@@ -1,4 +1,4 @@
-/* $Id: contact.h,v 1.64 2005/05/03 21:55:33 kuhlmann Exp $ */
+/* $Id: contact.h,v 1.67 2005/09/04 22:24:54 kuhlmann Exp $ */
 
 #ifndef MICQ_CONTACT_H
 #define MICQ_CONTACT_H
@@ -93,6 +93,7 @@ struct Contact_s
 {
     ContactGroup *group;
     char  *nick;
+    char  *screen;
     UDWORD uin;
     UDWORD status;
     UDWORD oldflags;
@@ -133,7 +134,7 @@ Contact      *ContactUIN          (Connection *serv, UDWORD uin DEBUGPARAM);
 Contact      *ContactScreen       (Connection *serv, const char *screen DEBUGPARAM);
 void          ContactCreate       (Connection *serv, Contact *cont DEBUGPARAM);
 Contact      *ContactFind         (ContactGroup *group, UWORD id, UDWORD uin, const char *nick);
-Contact      *ContactFindCreate   (ContactGroup *group, UWORD id, UDWORD uin, const char *nick DEBUGPARAM);
+Contact      *ContactFindCreate   (ContactGroup *group, UDWORD uin, const char *nick DEBUGPARAM);
 BOOL          ContactAdd          (ContactGroup *group, Contact *cont DEBUGPARAM);
 BOOL          ContactHas          (ContactGroup *group, Contact *cont);
 BOOL          ContactRem          (ContactGroup *group, Contact *cont DEBUGPARAM);
@@ -146,7 +147,7 @@ BOOL          ContactRemAlias     (Contact *cont, const char *nick DEBUGPARAM);
 #define ContactGroupD(g)           ContactGroupD(g DEBUGARGS)
 #define ContactUIN(c,u)            ContactUIN(c,u DEBUGARGS)
 #define ContactScreen(c,s)         ContactScreen(c,s DEBUGARGS)
-#define ContactFindCreate(g,i,u,n) ContactFindCreate(g,i,u,n DEBUGARGS)
+#define ContactFindCreate(g,u,n)   ContactFindCreate(g,u,n DEBUGARGS)
 #define ContactCreate(g,c)         ContactCreate(g,c DEBUGARGS)
 #define ContactAdd(g,c)            ContactAdd(g,c DEBUGARGS)
 #define ContactRem(g,c)            ContactRem(g,c DEBUGARGS)
@@ -155,6 +156,7 @@ BOOL          ContactRemAlias     (Contact *cont, const char *nick DEBUGPARAM);
 #define ContactRemAlias(c,n)       ContactRemAlias(c,n DEBUGARGS)
 
 ContactIDs   *ContactID           (Contact *cont, UWORD type);
+ContactIDs   *ContactIDHas        (Contact *cont, UWORD type);
 UWORD         ContactIDGet        (Contact *cont, UWORD type);
 void          ContactIDSet        (Contact *cont, UWORD type, UWORD id, UWORD tag);
 void          ContactSetCap       (Contact *cont, Cap *cap);
