@@ -1,4 +1,4 @@
-/* $Id: micq.h,v 1.90 2005/01/11 21:57:57 kuhlmann Exp $ */
+/* $Id: micq.h,v 1.93 2005/12/22 16:33:12 kuhlmann Exp $ */
 
 #ifndef MICQ_H
 #define MICQ_H
@@ -82,6 +82,8 @@ typedef struct Preferences_s  Preferences;
 typedef struct Cap_s          Cap;
 typedef struct Extra_s        Extra;
 
+typedef void MSN_Handle;
+
 #include "datatype.h"
 #include <stdlib.h>
 #ifdef HAVE_STRING_H
@@ -91,6 +93,8 @@ typedef struct Extra_s        Extra;
 #include <strings.h>
 #endif
 
+#include "autopackage_prefix.h"
+
 #if ENABLE_DEBUG && HAVE_VARIADIC_MACRO
 #define DEBUGARGS    , __FILE__, __LINE__
 #define DEBUGPARAM   , const char *debugfile, int debugline
@@ -134,26 +138,26 @@ typedef struct Extra_s        Extra;
 #include "icq_tcp.h"
 
 /* test in this order */
-#define STATUSF_INV       0x00000100
-#define STATUSF_DND       0x00000002
-#define STATUSF_OCC       0x00000010
-#define STATUSF_NA        0x00000004
-#define STATUSF_AWAY      0x00000001
-#define STATUSF_FFC       0x00000020
-#define STATUSF_BIRTH     0x00080000
-#define STATUSF_WEBAWARE  0x00010000
-#define STATUSF_IP        0x00020000
-#define STATUSF_DC_AUTH   0x10000000
-#define STATUSF_DC_CONT   0x20000000
+#define STATUSF_ICQINV       0x00000100
+#define STATUSF_ICQDND       0x00000002
+#define STATUSF_ICQOCC       0x00000010
+#define STATUSF_ICQNA        0x00000004
+#define STATUSF_ICQAWAY      0x00000001
+#define STATUSF_ICQFFC       0x00000020
+#define STATUSF_ICQBIRTH     0x00080000
+#define STATUSF_ICQWEBAWARE  0x00010000
+#define STATUSF_ICQIP        0x00020000
+#define STATUSF_ICQDC_AUTH   0x10000000
+#define STATUSF_ICQDC_CONT   0x20000000
 
-#define STATUS_OFFLINE    0xffffffff
-#define STATUS_INV         STATUSF_INV
-#define STATUS_DND        (STATUSF_DND | STATUSF_OCC | STATUSF_AWAY)
-#define STATUS_OCC        (STATUSF_OCC | STATUSF_AWAY)
-#define STATUS_NA         (STATUSF_NA  | STATUSF_AWAY)
-#define STATUS_AWAY        STATUSF_AWAY
-#define STATUS_FFC         STATUSF_FFC
-#define STATUS_ONLINE     0x00000000
+#define STATUS_ICQOFFLINE    0xffffffff
+#define STATUS_ICQINV         STATUSF_ICQINV
+#define STATUS_ICQDND        (STATUSF_ICQDND | STATUSF_ICQOCC | STATUSF_ICQAWAY)
+#define STATUS_ICQOCC        (STATUSF_ICQOCC | STATUSF_ICQAWAY)
+#define STATUS_ICQNA         (STATUSF_ICQNA  | STATUSF_ICQAWAY)
+#define STATUS_ICQAWAY        STATUSF_ICQAWAY
+#define STATUS_ICQFFC         STATUSF_ICQFFC
+#define STATUS_ICQONLINE     0x00000000
 
 #define MSGF_MASS         0x8000
 #define MSGF_GETAUTO      0x0300
