@@ -1,4 +1,4 @@
-/* $Id: packet.h,v 1.47 2005/02/10 21:17:18 kuhlmann Exp $ */
+/* $Id: packet.h,v 1.50 2005/12/05 21:28:35 kuhlmann Exp $ */
 
 #ifndef MICQ_PACKET_H
 #define MICQ_PACKET_H
@@ -31,12 +31,15 @@ struct Cap_s
 typedef enum {
   CAP_NONE = 0, CAP_AIM_VOICE, CAP_AIM_SFILE, CAP_ISICQ, CAP_AIM_IMIMAGE,
   CAP_AIM_BUDICON, CAP_AIM_STOCKS, CAP_AIM_GETFILE, CAP_SRVRELAY, CAP_AIM_GAMES,
-  CAP_AIM_SBUD, CAP_UTF8, CAP_RTFMSGS, CAP_IS_2001, CAP_STR_2001,
-  CAP_STR_2002, CAP_AIM_CHAT, CAP_TYPING,
+  CAP_AIM_SBUD, CAP_AIM_INTER, CAP_AVATAR,
+  CAP_UTF8, CAP_RTFMSGS, CAP_IS_2001, CAP_STR_2001,
+  CAP_STR_2002, CAP_AIM_CHAT, CAP_TYPING, CAP_XTRAZ,
   CAP_TRILL_CRYPT, CAP_TRILL_2, CAP_LICQ, CAP_LICQNEW, CAP_SIM, CAP_SIMNEW,
   CAP_MACICQ, CAP_MICQ, CAP_KXICQ, CAP_KOPETE,
-  CAP_IMSECURE, CAP_ARQ, CAP_UTF8ii, CAP_AIM_INTER,
-  CAP_WIERD1, CAP_WIERD2, CAP_WIERD3, CAP_WIERD4, CAP_WIERD5, CAP_11, CAP_12,
+  CAP_IMSECURE, CAP_ARQ, CAP_MIRANDA, CAP_QIP, CAP_IM2,
+  CAP_UTF8ii,
+  CAP_WIERD1, CAP_WIERD3, CAP_WIERD4, CAP_WIERD5, CAP_WIERD7,
+  CAP_11, CAP_12,
   CAP_MAX = 63
 } cap_id_t;
 
@@ -66,6 +69,7 @@ void        PacketWriteCapID  (      Packet *pak,           UBYTE id);
 void        PacketWriteData   (      Packet *pak,           const char *data, UWORD len);
 void        PacketWriteStr    (      Packet *pak,           const char *data);
 void        PacketWriteLNTS   (      Packet *pak,           const char *data);
+void        PacketWriteLNTS2  (      Packet *pak,           str_t data);
 void        PacketWriteDLStr  (      Packet *pak,           const char *data);
 void        PacketWriteLLNTS  (      Packet *pak,           const char *data);
 void        PacketWriteCont   (      Packet *pak, Contact *cont);
