@@ -1,7 +1,7 @@
 /*
  * Provides a build mark with the current version and current time of compilation.
  *
- * mICQ Copyright (C) © 2001-2005 Rüdiger Kuhlmann
+ * mICQ Copyright (C) © 2001-2006 Rüdiger Kuhlmann
  *
  * mICQ is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -26,10 +26,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: buildmark.c,v 1.74 2005/06/04 22:27:23 kuhlmann Exp $
+ * $Id: buildmark.c,v 1.76 2006/01/16 18:47:30 kuhlmann Exp $
  */
 
-#define MICQ_BUILD_NUM 0x00050004
+#define MICQ_BUILD_NUM 0x00050100
 
 #include "micq.h"
 #include "buildmark.h"
@@ -92,6 +92,12 @@
 #define EXTRAVERSION EXTRAVERSION_DEF " hand compiled"
 #endif
 
+#ifdef ENABLE_AUTOPACKAGE
+#define EV_AP "AP "
+#else
+#define EV_AP
+#endif
+
 #ifdef ENABLE_PEER2PEER
 #define EV_P2P "P2P "
 #else
@@ -110,7 +116,7 @@
 #define EV_SSL
 #endif
 
-#define EV EV_SSL EV_TCL EV_P2P
+#define EV EV_AP EV_SSL EV_TCL EV_P2P
 
 const UDWORD BuildPlatformID = BUILD_PLATFORM;
 
