@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: contact.c,v 1.121 2005/05/03 22:06:39 kuhlmann Exp $
+ * $Id: contact.c,v 1.133 2005/12/22 23:08:21 kuhlmann Exp $
  */
 
 #include <ctype.h>
@@ -53,33 +53,6 @@ static int            cnt_count = 0;
 #define CONTACTGROUP_GLOBAL      (cnt_groups[0])
 #define CONTACTGROUP_NONCONTACTS (cnt_groups[1])
 
-#define BUILD_MIRANDA  0xffffffffUL
-#define BUILD_MOBICQ   0xfffffffeUL
-#define BUILD_STRICQ   0xffffff8fUL
-#define BUILD_YSM      0xffffffabUL
-#define BUILD_ARQ      0xffffff7fUL
-#define BUILD_VICQ     0x04031980UL
-#define BUILD_ALICQ    0xffffffbeUL
-
-#define BUILD_LICQ     0x7d000000UL
-#define BUILD_SSL      0x00800000UL
-
-#define BUILD_TRILLIAN_ID1  0x3b75ac09UL
-#define BUILD_TRILLIAN_ID2  0x3bae70b6UL
-#define BUILD_TRILLIAN_ID3  0x3b744adbUL
-
-#define BUILD_LIBICQ2K_ID1  0x3aa773eeUL
-#define BUILD_LIBICQ2K_ID2  0x3aa66380UL
-#define BUILD_LIBICQ2K_ID3  0x3a877a42UL
-
-#define BUILD_KXICQ_ID1     0x3b4c4c0cUL
-#define BUILD_KXICQ_ID2     0UL
-#define BUILD_KXICQ_ID3     0x3b7248edUL
-
-#define BUILD_KXICQ2_ID1    0x3aa773eeUL
-#define BUILD_KXICQ2_ID2    0x3aa66380UL
-#define BUILD_KXICQ2_ID3    0x3a877a42UL
-
 /*
  * Initializes the contact group table.
  */
@@ -257,7 +230,7 @@ Contact *ContactIndex (ContactGroup *group, int i)
     return group->contacts[i];
 }
 
-static Contact *ContactC (UWORD id, UDWORD uin, const char *nick DEBUGPARAM)
+static Contact *ContactC (Connection *serv, UDWORD uin, const char *nick DEBUGPARAM)
 {
     Contact *cont;
 
@@ -266,11 +239,12 @@ static Contact *ContactC (UWORD id, UDWORD uin, const char *nick DEBUGPARAM)
 
     cont->uin = uin;
     cont->ids = NULL;
-    cont->status = STATUS_OFFLINE;
+    cont->status = STATUS_ICQOFFLINE;
     
     s_repl (&cont->nick, nick ? nick : s_sprintf ("%ld", uin));
+    s_repl (&cont->screen, nick && serv->type != TYPE_SERVER ? nick : s_sprintf ("%ld", uin));
 
-    Debug (DEB_CONTACT, "new   #%d %ld '%s' %p", id, uin, nick, cont);
+    Debug (DEB_CONTACT, "new  %p %ld '%s' '%s' %p", cont, uin, cont->screen, cont->nick, cont);
     ContactAdd (CONTACTGROUP_GLOBAL, cont);
     return cont;
 }
@@ -279,21 +253,21 @@ static Contact *ContactC (UWORD id, UDWORD uin, const char *nick DEBUGPARAM)
  * Finds a contact for a connection
  */
 #undef ContactScreen
-Contact *ContactScreen (Connection *conn, const char *screen DEBUGPARAM)
+Contact *ContactScreen (Connection *serv, const char *screen DEBUGPARAM)
 {
     Contact *cont;
     UDWORD uin = atoi (screen);
     
-    if (!conn || !conn->contacts || !uin)
+    if (!serv || !serv->contacts || !uin)
         return NULL;
 
     if (!cnt_groups)
         ContactGroupInit ();
 
-    if (uin && (cont = ContactFind (conn->contacts, 0, uin, NULL)))
+    if (uin && (cont = ContactFind (serv->contacts, 0, uin, NULL)))
         return cont;
     
-    if ((cont = ContactFind (conn->contacts, 0, uin, screen)))
+    if ((cont = ContactFind (serv->contacts, 0, uin, screen)))
         return cont;
     
     if (uin && (cont = ContactFind (CONTACTGROUP_NONCONTACTS, 0, uin, NULL)))
@@ -302,7 +276,7 @@ Contact *ContactScreen (Connection *conn, const char *screen DEBUGPARAM)
     if ((cont = ContactFind (CONTACTGROUP_NONCONTACTS, 0, uin, screen)))
         return cont;
 
-    if (!(cont = ContactC (0, uin, screen DEBUGFOR)))
+    if (!(cont = ContactC (serv, uin, screen DEBUGFOR)))
         return NULL;
 
     ContactAdd (CONTACTGROUP_NONCONTACTS, cont);
@@ -313,23 +287,23 @@ Contact *ContactScreen (Connection *conn, const char *screen DEBUGPARAM)
  * Finds a contact for a connection
  */
 #undef ContactUIN
-Contact *ContactUIN (Connection *conn, UDWORD uin DEBUGPARAM)
+Contact *ContactUIN (Connection *serv, UDWORD uin DEBUGPARAM)
 {
     Contact *cont;
     
-    if (!conn || !conn->contacts || !uin)
+    if (!serv || !serv->contacts || !uin)
         return NULL;
 
     if (!cnt_groups)
         ContactGroupInit ();
 
-    if ((cont = ContactFind (conn->contacts, 0, uin, NULL)))
+    if ((cont = ContactFind (serv->contacts, 0, uin, NULL)))
         return cont;
     
     if ((cont = ContactFind (CONTACTGROUP_NONCONTACTS, 0, uin, NULL)))
         return cont;
 
-    if (!(cont = ContactC (0, uin, NULL DEBUGFOR)))
+    if (!(cont = ContactC (serv, uin, NULL DEBUGFOR)))
         return NULL;
 
     ContactAdd (CONTACTGROUP_NONCONTACTS, cont);
@@ -365,7 +339,7 @@ Contact *ContactFind (ContactGroup *group, UWORD id, UDWORD uin, const char *nic
                 if (!ids)
                     continue;
             }
-            if (!nick || !strcmp (nick, cont->nick))
+            if (!nick || !strcmp (nick, cont->screen) || !strcmp (nick, cont->nick))
                 return cont;
             for (ca = cont->alias; ca; ca = ca->more)
                 if (!strcmp (nick, ca->alias))
@@ -392,24 +366,24 @@ void ContactCreate (Connection *serv, Contact *cont DEBUGPARAM)
  * Finds a contact on a contact group, possibly creating it
  */
 #undef ContactFindCreate
-Contact *ContactFindCreate (ContactGroup *group, UWORD id, UDWORD uin, const char *nick DEBUGPARAM)
+Contact *ContactFindCreate (ContactGroup *group, UDWORD uin, const char *nick DEBUGPARAM)
 {
     Contact *cont;
     
     if (!group && !cnt_groups)
         ContactGroupInit ();
 
-    assert (id || uin);
+    assert (uin || (group->serv->type != TYPE_SERVER));
     assert (group);
 
-    if ((cont = ContactFind (group, id, uin, NULL)))
+    if ((cont = ContactFind (group, 0, uin, NULL)))
     {
         if (nick)
             ContactAddAlias (cont, nick);
         return cont;
     }
     
-    if ((cont = ContactFind (CONTACTGROUP_NONCONTACTS, id, uin, NULL)))
+    if ((cont = ContactFind (CONTACTGROUP_NONCONTACTS, 0, uin, NULL)))
     {
         if (!nick)
             return cont;
@@ -417,23 +391,23 @@ Contact *ContactFindCreate (ContactGroup *group, UWORD id, UDWORD uin, const cha
         ContactAdd (group, cont);
         cont->group = group;
         s_repl (&cont->nick, nick);
-        Debug (DEB_CONTACT, "act   #%d %ld '%s' %p in %p", id, uin, nick, cont, group);
+        Debug (DEB_CONTACT, "act   %ld '%s' %p in %p", uin, nick, cont, group);
         return cont;
     }
     
-    if (!(cont = ContactC (id, uin, nick DEBUGFOR)))
+    if (!(cont = ContactC (group->serv, uin, nick DEBUGFOR)))
         return NULL;
 
     if (nick)
     {
         ContactAdd (group, cont);
         cont->group = group;
-        Debug (DEB_CONTACT, "act   #%d %ld '%s' %p", id, uin, nick, cont);
+        Debug (DEB_CONTACT, "act   %ld '%s' %p", uin, nick, cont);
     }
     else
     {
         ContactAdd (CONTACTGROUP_NONCONTACTS, cont);
-        Debug (DEB_CONTACT, "temp  #%d %ld %p", id, uin, cont);
+        Debug (DEB_CONTACT, "temp  %ld %p", uin, cont);
     }
 
     return cont;
@@ -557,6 +531,13 @@ BOOL ContactRem (ContactGroup *group, Contact *cont DEBUGPARAM)
                     group->contacts[i] = group->contacts[--group->used];
                     group->contacts[group->used] = NULL;
                 }
+                if (cont->group == orig && orig)
+                {
+                    if (cont->group->serv)
+                        cont->group = cont->group->serv->contacts;
+                    else
+                        cont->group = NULL;
+                }
                 Debug (DEB_CONTACT, "rem   #%d %ld '%s' %p to %p", 0, cont->uin, cont->nick, cont, orig);
                 return TRUE;
             }
@@ -651,7 +632,21 @@ BOOL ContactRemAlias (Contact *cont, const char *nick DEBUGPARAM)
 }
 
 /*
- * Returns the contact id for flag, if necessary create one
+ * Returns the contact id for type, if available
+ */
+ContactIDs *ContactIDHas (Contact *cont, UWORD type)
+{
+    ContactIDs *ids;
+    
+    for (ids = cont->ids; ids; ids = ids->next)
+        if (ids->type == type)
+            return ids;
+    
+    return NULL;
+}
+
+/*
+ * Returns the contact id for type, if necessary create one
  */
 ContactIDs *ContactID (Contact *cont, UWORD type)
 {
@@ -1111,12 +1106,45 @@ void ContactSetCap (Contact *cont, Cap *cap)
         cont->v3 = cap->var[14];
         cont->v4 = cap->var[15];
     }
+    else if (cap->var && (cap->id == CAP_MIRANDA))
+    {
+        cont->v1 = cap->var[8];
+        cont->v2 = cap->var[9];
+        cont->v3 = cap->var[10];
+        cont->v4 = cap->var[11];
+    }
+    else if (cap->var && (cap->id == CAP_ARQ))
+    {
+        cont->v1 = cap->var[9];
+        cont->v2 = cap->var[10];
+        cont->v3 = cap->var[11];
+        cont->v4 = cap->var[12];
+    }
     SET_CAP (cont->caps, cap->id);
 }
 
 /*
  * Guess the contacts client from time stamps.
  */
+#define BUILD_LICQ     0x7d000000UL
+#define BUILD_SSL      0x00800000UL
+
+#define BUILD_TRILLIAN_ID1  0x3b75ac09UL
+#define BUILD_TRILLIAN_ID2  0x3bae70b6UL
+#define BUILD_TRILLIAN_ID3  0x3b744adbUL
+
+#define BUILD_LIBICQ2K_ID1  0x3aa773eeUL
+#define BUILD_LIBICQ2K_ID2  0x3aa66380UL
+#define BUILD_LIBICQ2K_ID3  0x3a877a42UL
+
+#define BUILD_KXICQ_ID1     0x3b4c4c0cUL
+#define BUILD_KXICQ_ID2     0UL
+#define BUILD_KXICQ_ID3     0x3b7248edUL
+
+#define BUILD_KXICQ2_ID1    0x3aa773eeUL
+#define BUILD_KXICQ2_ID2    0x3aa66380UL
+#define BUILD_KXICQ2_ID3    0x3a877a42UL
+
 void ContactSetVersion (Contact *cont)
 {
     char buf[100];
@@ -1132,12 +1160,70 @@ void ContactSetVersion (Contact *cont)
     
     ver = dc->id1 & 0xffff;
     
-    if (!HAS_CAP (cont->caps, CAP_SIM) && !HAS_CAP (cont->caps, CAP_MICQ)
-        && !HAS_CAP (cont->caps, CAP_SIMNEW) && !HAS_CAP (cont->caps, CAP_KOPETE)
-        && !HAS_CAP (cont->caps, CAP_LICQNEW))
-        cont->v1 = cont->v2 = cont->v3 = cont->v4 = 0;
-
-    if ((dc->id1 & 0xff7f0000UL) == BUILD_LICQ && ver > 1000)
+    if (HAS_CAP (cont->caps, CAP_MICQ))
+    {
+        new = "mICQ";
+        OptSetVal (&cont->copts, CO_TIMEMICQ, time (NULL));
+        if (cont->v1 & 0x80)
+            tail = " cvs";
+        cont->v1 &= ~0x80;
+    }
+    else if (HAS_CAP (cont->caps, CAP_SIMNEW))
+    {
+        new = "SIM";
+        if (cont->v4 & 0x80)
+            tail = "/w32";
+        else if (cont->v4 & 0x40)
+            tail = "/OSX";
+    }
+    else if (HAS_CAP (cont->caps, CAP_LICQNEW))
+    {
+        new = "licq";
+        if (cont->v2 / 100 == cont->v1)
+            cont->v2 %= 100; /* bug in licq 1.3.0 */
+        if (cont->v4 == 1)
+            tail = "/SSL";
+    }
+    else if (HAS_CAP (cont->caps, CAP_KOPETE))
+        new = "Kopete";
+    else if (HAS_CAP (cont->caps, CAP_MIRANDA))
+    {
+        new = "Miranda";
+        if (((cont->v1 << 24) | (cont->v2 << 16) | (cont->v3 << 8) | cont->v4) <= 0x00010202 && dc->version >= 8)
+            dc->version = 7;
+        if (cont->v1 & 0x80)
+            tail = " cvs";
+        cont->v1 &= ~0x80;
+    }
+    else if (HAS_CAP (cont->caps, CAP_SIM))
+    {
+        if (cont->v1 || cont->v2)
+            new = "SIM";
+        else
+            new = "Kopete";
+    }
+    else if (HAS_CAP (cont->caps, CAP_ARQ))
+        new = "&RQ";
+    else if ((cont->v1 = cont->v2 = cont->v3 = cont->v4 = 0))
+        assert (0);
+    else if (HAS_CAP (cont->caps, CAP_TRILL_CRYPT) || HAS_CAP (cont->caps, CAP_TRILL_2))
+    {
+        if (HAS_CAP (cont->caps, CAP_RTFMSGS))
+            new = "Trillian v3";
+        else
+            new = "Trillian";
+    }
+    else if (HAS_CAP (cont->caps, CAP_LICQ))
+        new = "licq";
+    else if (HAS_CAP (cont->caps, CAP_MACICQ))
+        new = "ICQ for Mac";
+    else if (HAS_CAP (cont->caps, CAP_KXICQ))
+        new = "KXicq2";
+    else if (HAS_CAP (cont->caps, CAP_IM2))
+        new = "IM2";
+    else if (HAS_CAP (cont->caps, CAP_QIP))
+        new = "QIP";
+    else if ((dc->id1 & 0xff7f0000UL) == BUILD_LICQ && ver > 1000)
     {
         new = "licq";
         if (dc->id1 & BUILD_SSL)
@@ -1147,19 +1233,6 @@ void ContactSetVersion (Contact *cont)
         cont->v3 = ver % 10;
         cont->v4 = 0;
     }
-#ifdef WIP
-    else if ((dc->id1 & 0xff7f0000UL) == BUILD_MICQ || (dc->id1 & 0xff7f0000UL) == BUILD_LICQ)
-    {
-        new = "mICQ";
-        cont->v1 = ver / 10000;
-        cont->v2 = (ver / 100) % 100;
-        cont->v3 = (ver / 10) % 10;
-        cont->v4 = ver % 10;
-        if (ver >= 489 && dc->id2)
-            dc->id1 = BUILD_MICQ;
-    }
-#endif
-
     else if ((dc->id1 & 0xffff0000UL) == 0xffff0000UL)
     {
         cont->v1 = (dc->id2 & 0x7f000000) >> 24;
@@ -1168,17 +1241,24 @@ void ContactSetVersion (Contact *cont)
         cont->v4 =  dc->id2 &       0xff;
         switch ((UDWORD)dc->id1)
         {
-            case BUILD_MIRANDA:
-                if (dc->id2 <= 0x00010202 && dc->version >= 8)
-                    dc->version = 7;
-                new = "Miranda";
-                if (dc->id2 & 0x80000000)
-                    tail = " cvs";
+            case 0xffffffffUL:
+                if (((UDWORD)dc->id2) == 0xffffffffUL)
+                    new = "Gaim";
+                else if (!dc->id2 && dc->version == 7)
+                    new = "WebICQ";
+                else
+                {
+                    if (dc->id2 <= 0x00010202 && dc->version >= 8)
+                        dc->version = 7;
+                    new = "Miranda";
+                    if (dc->id2 & 0x80000000)
+                        tail = " cvs";
+                }
                 break;
-            case BUILD_MOBICQ:
+            case 0xfffffffeUL:
                 new = "MobICQ";
                 break;
-            case BUILD_STRICQ:
+            case 0xffffff8fUL:
                 new = "StrICQ";
                 break;
             case BUILD_MICQ:
@@ -1187,15 +1267,15 @@ void ContactSetVersion (Contact *cont)
                 if (dc->id2 & 0x80000000)
                     tail = " cvs";
                 break;
-            case BUILD_YSM:
+            case 0xffffffabUL:
                 new = "YSM";
                 if ((cont->v1 | cont->v2 | cont->v3 | cont->v4) & 0x80)
                     cont->v1 = cont->v2 = cont->v3 = cont->v4 = 0;
                 break;
-            case BUILD_ARQ:
+            case 0xffffff7fUL:
                 new = "&RQ";
                 break;
-            case BUILD_ALICQ:
+            case 0xffffffbeUL:
                 new = "alicq";
                 break;
             default:
@@ -1203,7 +1283,7 @@ void ContactSetVersion (Contact *cont)
                 new = buf;
         }
     }
-    else if (dc->id1 == BUILD_VICQ)
+    else if (dc->id1 == 0x04031980UL)
     {
         cont->v1 = 0;
         cont->v2 = 43;
@@ -1223,7 +1303,12 @@ void ContactSetVersion (Contact *cont)
              dc->id2 == BUILD_LIBICQ2K_ID2 &&
              dc->id3 == BUILD_LIBICQ2K_ID3)
     {
-        new = "libicq2000";
+        if (HAS_CAP (cont->caps, CAP_RTFMSGS))
+            new = "centericq";
+        else if (HAS_CAP (cont->caps, CAP_UTF8))
+            new = "IcyJuice";
+        else
+            new = "libicq2000";
     }
     else if (dc->id1 == BUILD_KXICQ_ID1 &&
              dc->id2 == BUILD_KXICQ_ID2 &&
@@ -1237,63 +1322,57 @@ void ContactSetVersion (Contact *cont)
     {
         new = "KXicq2 > 0.7.6";
     }
-    else if (HAS_CAP (cont->caps, CAP_TRILL_CRYPT | CAP_TRILL_2))
-        new = "Trillian";
-    else if (HAS_CAP (cont->caps, CAP_LICQ))
-        new = "licq";
-    else if (HAS_CAP (cont->caps, CAP_SIM))
-    {
-        if (cont->v1 || cont->v2)
-            new = "SIM";
-        else
-            new = "Kopete";
-    }
-    else if (HAS_CAP (cont->caps, CAP_MICQ))
-    {
-        new = "mICQ";
-        OptSetVal (&cont->copts, CO_TIMEMICQ, time (NULL));
-    }
-    else if (HAS_CAP (cont->caps, CAP_SIMNEW))
-        new = "SIM";
-    else if (HAS_CAP (cont->caps, CAP_LICQNEW))
-    {
-        new = "licq";
-        if (cont->v2 / 100 == cont->v1)
-            cont->v2 %= 100; /* bug in licq 1.3.0 */
-        if (cont->v4 == 1)
-            tail = "/SSL";
-    }
-    else if (HAS_CAP (cont->caps, CAP_KOPETE))
-        new = "Kopete";
+    else if (dc->id1 == 0x3FF19BEBUL &&
+             dc->id2 == 0x3FF19BEBUL)
+        new = "IM2";
     else if (dc->id1 == dc->id2 && dc->id2 == dc->id3 && dc->id1 == -1)
         new = "vICQ/GAIM(?)";
+    else if (dc->version == 7 && HAS_CAP (cont->caps, CAP_RTFMSGS))
+        new = "GnomeICU";
+    else if (dc->version == 7 && HAS_CAP (cont->caps, CAP_SRVRELAY))
+        new = "ICQ 2000";
     else if (dc->version == 7 && HAS_CAP (cont->caps, CAP_TYPING))
-        new = "ICQ2go";
-    else if (dc->version == 9 && HAS_CAP (cont->caps, CAP_TYPING))
+        new = "ICQ2go (Java)";
+    else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_STR_2002) && HAS_CAP (cont->caps, CAP_UTF8))
+        new = "ICQ 2002";
+    else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_STR_2001) && HAS_CAP (cont->caps, CAP_IS_2001) && !dc->id1 && !dc->id2 && !dc->id3)
+        new = "ICQ for Pocket PC";
+    else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_STR_2001) && HAS_CAP (cont->caps, CAP_IS_2001))
+        new = "ICQ 2001";
+    else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_SRVRELAY) && HAS_CAP (cont->caps, CAP_RTFMSGS))
+        new = "ICQ 2002/2003a";
+    else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_UTF8) && HAS_CAP (cont->caps, CAP_RTFMSGS))
+        new = "ICQ 2002/2003a";
+    else if (dc->version == 9 && HAS_CAP (cont->caps, CAP_TYPING) && HAS_CAP (cont->caps, CAP_XTRAZ) && HAS_CAP (cont->caps, CAP_AIM_SFILE))
+        new = "ICQ5";
+    else if (dc->version == 9 && HAS_CAP (cont->caps, CAP_TYPING) && HAS_CAP (cont->caps, CAP_XTRAZ))
         new = "ICQ Lite";
     else if (dc->version == 10 && HAS_CAP (cont->caps, CAP_STR_2002) && HAS_CAP (cont->caps, CAP_UTF8))
-        new = "ICQ 2003";
-    else if (HAS_CAP (cont->caps, CAP_STR_2002) && HAS_CAP (cont->caps, CAP_UTF8))
-        new = "ICQ 2002";
-    else if (HAS_CAP (cont->caps, CAP_STR_2001) && HAS_CAP (cont->caps, CAP_IS_2001))
-        new = "ICQ 2001";
-    else if (HAS_CAP (cont->caps, CAP_MACICQ))
-        new = "ICQ for Mac";
-    else if (HAS_CAP (cont->caps, CAP_KXICQ))
-        new = "KXicq2";
+        new = "ICQ 2003b";
+    else if (dc->version == 10 && HAS_CAP (cont->caps, CAP_STR_2002) && HAS_CAP (cont->caps, CAP_RTFMSGS))
+        new = "ICQ 2003b";
+    else if (dc->version == 10 && HAS_CAP (cont->caps, CAP_UTF8))
+        new = "ICQ 2003b (?)";
+    else if (dc->version == 10 && HAS_CAP (cont->caps, CAP_RTFMSGS))
+        new = "ICQ 2003b (?)";
+    else if (dc->version == 10)
+    {
+        CLR_CAP (cont->caps, CAP_SRVRELAY);
+        new = "QNext";
+    }
     else if (HAS_CAP (cont->caps, CAP_AIM_SFILE) && HAS_CAP(cont->caps, CAP_AIM_IMIMAGE)
           && HAS_CAP (cont->caps, CAP_AIM_BUDICON) && HAS_CAP(cont->caps, CAP_UTF8))
         new = "GAIM (ICQ) (?)";
+    else if (dc->version == 9 && HAS_CAP (cont->caps, CAP_TYPING))
+        new = "ICQ Lite (?)";
     else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_UTF8))
         new = "ICQ 2002 (?)";
     else if (dc->version == 8 && HAS_CAP (cont->caps, CAP_IS_2001))
         new = "ICQ 2001 (?)";
+    else if (dc->version == 7)
+        new = "ICQ2go (?)";
     else if (HAS_CAP (cont->caps, CAP_AIM_CHAT))
         new = "AIM(?)";
-    else if (dc->version == 7 && !HAS_CAP (cont->caps, CAP_RTFMSGS))
-        new = "ICQ 2000 (?)";
-    else if (dc->version == 10 && HAS_CAP (cont->caps, CAP_UTF8))
-        new = "ICQ 2003 (?)";
     else if (!dc->version && HAS_CAP (cont->caps, CAP_UTF8))
         new = "ICQ 2002 (?)";
     else if (!dc->version && HAS_CAP (cont->caps, CAP_IS_2001))
@@ -1302,6 +1381,16 @@ void ContactSetVersion (Contact *cont)
         new = "AIM(?)";
     else if (!dc->version && !HAS_CAP (cont->caps, CAP_RTFMSGS))
         new = "ICQ 2000 (?)";
+    else if (dc->version == 8)
+        new = "ICQ 2001 (?)";
+    else if (dc->version == 9)
+        new = "ICQ Lite (""?""?)";
+    else if (dc->version == 6)
+        new = "ICQ99";
+    else if (dc->version == 4)
+        new = "ICQ98";
+    else
+        new = "??";
     
     if (new)
     {
