@@ -27,7 +27,7 @@
  * 02111-1307, USA.
  *
  *
- * $Id: conv.c,v 1.70 2005/05/18 20:57:30 kuhlmann Exp $
+ * $Id: conv.c,v 1.71 2005/07/08 20:58:20 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -458,7 +458,6 @@ strc_t ConvFromSplit (strc_t text, UBYTE enc)
     
     s_init (&str, "", 100);
     tstr.txt = (char *)text->txt;
-    tstr.len = text->len;
     tstr.max = 0;
     while ((p = memchr (tstr.txt, '\xfe', tlen)))
     {
@@ -468,6 +467,7 @@ strc_t ConvFromSplit (strc_t text, UBYTE enc)
         tstr.txt += tstr.len + 1;
         tlen     -= tstr.len + 1;
     }
+    tstr.len = tlen;
     s_cat (&str, ConvFrom (&tstr, enc)->txt);
     return &str;
 }
