@@ -1,4 +1,4 @@
-/* $Id: file_util.c,v 1.208 2005/05/28 15:52:32 kuhlmann Exp $ */
+/* $Id: file_util.c,v 1.215 2005/12/22 16:33:16 kuhlmann Exp $ */
 /* Copyright: This file may be distributed under version 2 of the GPL licence. */
 
 #include "micq.h"
@@ -44,6 +44,7 @@
 #include "connection.h"
 #include "util_parse.h"
 #include "util_rl.h"
+#include "msn_base.h"
 
 /****/
 
@@ -63,9 +64,10 @@ Connection *PrefNewConnection (UDWORD uin, const char *passwd)
     conn->flags |= CONN_AUTOLOGIN;
     conn->pref_server = strdup ("login.icq.com");
     conn->pref_port = 5190;
-    conn->pref_status = STATUS_ONLINE;
+    conn->pref_status = STATUS_ICQONLINE;
     conn->version = 8;
     conn->uin = uin;
+    s_repl (&conn->screen, s_sprintf ("%lu", uin));
 #ifdef __BEOS__
     conn->pref_passwd = passwd ? strdup (passwd) : NULL;
 #endif
@@ -73,12 +75,12 @@ Connection *PrefNewConnection (UDWORD uin, const char *passwd)
     conn->server  = strdup ("login.icq.com");
     conn->port    = 5190;
     conn->passwd  = passwd ? strdup (passwd) : NULL;
-    conn->status = STATUS_ONLINE;
+    conn->status = STATUS_ICQONLINE;
 
     conn->contacts = ContactGroupC (conn, 0, s_sprintf ("contacts-icq8-%ld", uin));
     OptSetVal (&conn->contacts->copts, CO_IGNORE, 0);
-    cont = ContactFindCreate (conn->contacts, 0, 82274703, "mICQ");
-    ContactFindCreate (conn->contacts, 0, 82274703, "Tadu");
+    cont = ContactFindCreate (conn->contacts, 82274703, "mICQ");
+    ContactFindCreate (conn->contacts, 82274703, "Tadu");
     OptSetStr (&cont->copts, CO_COLORINCOMING, OptC2S ("red bold"));
     OptSetStr (&cont->copts, CO_COLORMESSAGE, OptC2S ("red bold"));
     rl_printf (i18n (2381, "I'll add the author of mICQ to your contact list for your convenience. Don't abuse this opportunity - please use the help command and make a serious attempt to read the man pages and the FAQ before asking questions.\n"));
@@ -211,8 +213,8 @@ void Initialize_RC_File ()
         conn->open = &ConnectionInitServer;
         conn->contacts = ContactGroupC (conn, 0, s_sprintf ("contacts-icq8-%ld", uin));
         OptSetVal (&conn->contacts->copts, CO_IGNORE, 0);
-        cont = ContactFindCreate (conn->contacts, 0, 82274703, "mICQ");
-        ContactFindCreate (conn->contacts, 0, 82274703, "Tadu");
+        cont = ContactFindCreate (conn->contacts, 82274703, "mICQ");
+        ContactFindCreate (conn->contacts, 82274703, "Tadu");
         OptSetStr (&cont->copts, CO_COLORINCOMING, OptC2S ("red bold"));
         OptSetStr (&cont->copts, CO_COLORMESSAGE, OptC2S ("red bold"));
     }
@@ -242,7 +244,7 @@ void Initialize_RC_File ()
     prG->logplace  = strdup ("history" _OS_PATHSEPSTR);
     prG->chat      = 49;
     prG->autoupdate = AUTOUPDATE_CURRENT;
-    prG->status = STATUS_ONLINE;
+    prG->status = STATUS_ICQONLINE;
     prG->flags = FLAG_DELBS | FLAG_AUTOSAVE;
 #ifdef ANSI_TERM
     prG->flags |= FLAG_COLOR;
@@ -253,7 +255,9 @@ void Initialize_RC_File ()
     OptSetVal (&prG->copts, CO_LOGCHANGE,  1);
     OptSetVal (&prG->copts, CO_SHOWONOFF,  1);
     OptSetVal (&prG->copts, CO_SHOWCHANGE, 1);
+    OptSetVal (&prG->copts, CO_AUTOAUTO,   0);
     OptSetVal (&prG->copts, CO_WANTSBL,    1);
+    OptSetVal (&prG->copts, CO_PEEKME,     0);
     OptSetVal (&prG->copts, CO_REVEALTIME, 600);
 
     OptSetStr (&prG->copts, CO_AUTODND,  i18n (1929, "User is dnd [Auto-Message]"));
@@ -871,7 +875,7 @@ int Read_RC_File (FILE *rcf)
                             break;
                     if (!tconn)
                         break;
-                    if (!(cont = ContactFindCreate (tconn->contacts, 0, uin, cmd)))
+                    if (!(cont = ContactFindCreate (tconn->contacts, uin, cmd)))
                     {
                         rl_printf ("%s%s%s %s\n", COLERROR, i18n (1619, "Warning:"), COLNONE,
                                  i18n (1620, "maximal number of contacts reached. Ask a wizard to enlarge me!"));
@@ -940,6 +944,8 @@ int Read_RC_File (FILE *rcf)
                         conn->type = TYPE_SERVER;
                     else if (!strcasecmp (cmd, "icq5"))
                         conn->type = TYPE_SERVER_OLD;
+                    else if (!strcasecmp (cmd, "msn"))
+                        conn->type = TYPE_MSN_SERVER;
                     else if (!strcasecmp (cmd, "peer"))
                     {
                         conn->type = TYPE_MSGLISTEN;
@@ -995,6 +1001,12 @@ int Read_RC_File (FILE *rcf)
                 {
                     PrefParseInt (i);
                     conn->uin = i;
+                    s_repl (&conn->screen, s_sprintf ("%lu", i));
+                }
+                else if (!strcasecmp (cmd, "screen"))
+                {
+                    PrefParse (tmp);
+                    s_repl (&conn->screen, tmp);
                 }
                 else if (!strcasecmp (cmd, "password"))
                 {
@@ -1030,6 +1042,7 @@ int Read_RC_File (FILE *rcf)
                         
                         if      (!strncmp (cg->name + 9, "icq5-", 5)) type = TYPE_SERVER_OLD;
                         else if (!strncmp (cg->name + 9, "icq8-", 5)) type = TYPE_SERVER;
+                        else if (!strncmp (cg->name + 9, "msn-", 4))  type = TYPE_MSN_SERVER;
                         
                         if (type)
                         {
@@ -1068,6 +1081,7 @@ int Read_RC_File (FILE *rcf)
                     PrefParse (tmp);
                     if      (!strcasecmp (tmp, "icq5")) type = TYPE_SERVER_OLD;
                     else if (!strcasecmp (tmp, "icq8")) type = TYPE_SERVER;
+                    else if (!strcasecmp (tmp, "msn"))  type = TYPE_MSN_SERVER;
                     else
                         ERROR;
                     
@@ -1089,7 +1103,7 @@ int Read_RC_File (FILE *rcf)
                     PrefParseInt (i);
                     PrefParseInt (uin);
                     
-                    cont = ContactFindCreate (cg->serv->contacts, i, uin, s_sprintf ("%ld", uin));
+                    cont = ContactFindCreate (cg->serv->contacts, uin, s_sprintf ("%ld", uin));
                     if (cont && cg != cg->serv->contacts)
                         ContactAdd (cg, cont);
                 }
@@ -1125,6 +1139,11 @@ int Read_RC_File (FILE *rcf)
             case TYPE_SERVER_OLD:
                 conn->open = &ConnectionInitServerV5;
                 break;
+#ifdef ENABLE_MSN
+            case TYPE_MSN_SERVER:
+                conn->open = &ConnectionInitMSNServer;
+                break;
+#endif
 #ifdef ENABLE_PEER2PEER
             case TYPE_MSGLISTEN:
                 conn->open = &ConnectionInitPeer;
@@ -1143,9 +1162,9 @@ int Read_RC_File (FILE *rcf)
         }
         if (format < 2 && !conn->contacts && conn->type & TYPEF_SERVER)
         {
-            conn->contacts = cg = ContactGroupC (conn, 0, s_sprintf ("contacts-%s-%ld", conn->type == TYPE_SERVER ? "icq8" : "icq5", conn->uin));
+            conn->contacts = cg = ContactGroupC (conn, 0, s_sprintf ("contacts-%s-%ld", ConnectionServerType (conn), conn->uin));
             for (i = 0; (cont = ContactIndex (NULL, i)); i++)
-                ContactFindCreate (cg, 0, cont->uin, cont->nick);
+                ContactFindCreate (cg, cont->uin, cont->nick);
             dep = 21;
         }
     }
@@ -1262,6 +1281,7 @@ void PrefReadStat (FILE *stf)
                         
                         if      (!strncmp (cg->name + 9, "icq5-", 5)) type = TYPE_SERVER_OLD;
                         else if (!strncmp (cg->name + 9, "icq8-", 5)) type = TYPE_SERVER;
+                        else if (!strncmp (cg->name + 9, "msn-", 4))  type = TYPE_MSN_SERVER;
                         else
                             break;
                         
@@ -1296,6 +1316,7 @@ void PrefReadStat (FILE *stf)
                     PrefParse (cmd);
                     if      (!strcasecmp (cmd, "icq5")) type = TYPE_SERVER_OLD;
                     else if (!strcasecmp (cmd, "icq8")) type = TYPE_SERVER;
+                    else if (!strcasecmp (cmd, "msn"))  type = TYPE_MSN_SERVER;
                     else
                         ERROR;
                     
@@ -1323,7 +1344,7 @@ void PrefReadStat (FILE *stf)
                     }
                     
                     if (format == 1)
-                        cont = ContactFindCreate (cg->serv->contacts, i, uin, s_sprintf ("%ld", uin));
+                        cont = ContactFindCreate (cg->serv->contacts, uin, s_sprintf ("%ld", uin));
                     else
                         cont = ContactFind (cg->serv->contacts, 0, uin, NULL);
                     
@@ -1396,6 +1417,7 @@ void PrefReadStat (FILE *stf)
                     PrefParse (cmd);
                     if      (!strcasecmp (cmd, "icq5")) type = TYPE_SERVER_OLD;
                     else if (!strcasecmp (cmd, "icq8")) type = TYPE_SERVER;
+                    else if (!strcasecmp (cmd, "msn"))  type = TYPE_MSN_SERVER;
                     else
                         ERROR;
                     
@@ -1405,7 +1427,7 @@ void PrefReadStat (FILE *stf)
                         ERROR;
                     if (!conn->contacts)
                     {
-                        conn->contacts = ContactGroupC (conn, 0, s_sprintf ("contacts-%s-%ld", conn->type == TYPE_SERVER ? "icq8" : "icq5", conn->uin));
+                        conn->contacts = ContactGroupC (conn, 0, s_sprintf ("contacts-%s-%ld", ConnectionServerType (conn), conn->uin));
                         OptSetVal (&conn->contacts->copts, CO_IGNORE, 0);
                         conn->contacts->serv = conn;
                     }
@@ -1419,7 +1441,7 @@ void PrefReadStat (FILE *stf)
                     PrefParseInt (uin);
                     PrefParse (cmd);
                     
-                    cont = ContactFindCreate (conn->contacts, id, uin, cmd);
+                    cont = ContactFindCreate (conn->contacts, uin, cmd);
                     if (!cont)
                         ERROR;
                     
@@ -1446,11 +1468,11 @@ void PrefReadStat (FILE *stf)
     
     for (i = 0; (conn = ConnectionNr (i)); i++)
     {
-        if (conn->type & TYPEF_SERVER)
+        if (conn->type & TYPEF_SERVER || conn->type == TYPE_MSN_SERVER)
         {
             if (!conn->contacts)
             {
-                conn->contacts = cg = ContactGroupC (conn, 0, s_sprintf ("contacts-%s-%ld", conn->type == TYPE_SERVER ? "icq8" : "icq5", conn->uin));
+                conn->contacts = cg = ContactGroupC (conn, 0, s_sprintf ("contacts-%s-%ld", ConnectionServerType (conn), conn->uin));
                 OptSetVal (&cg->copts, CO_IGNORE, 0);
                 dep = 21;
             }
@@ -1520,7 +1542,7 @@ int PrefWriteStatusFile (void)
             continue;
 
         fprintf (stf, "[Contacts]\n");
-        fprintf (stf, "server %s %ld\n", ss->type == TYPE_SERVER ? "icq8" : "icq5", ss->uin);
+        fprintf (stf, "server %s %ld\n", ConnectionServerType (ss), ss->uin);
         fprintf (stf, "%s\n", OptString (&ss->contacts->copts));
 
         for (i = 0; (cont = ContactIndex (0, i)); i++)
@@ -1544,7 +1566,7 @@ int PrefWriteStatusFile (void)
             continue;
 
         fprintf (stf, "\n[Group]\n");
-        fprintf (stf, "server %s %ld\n", cg->serv->type == TYPE_SERVER ? "icq8" : "icq5", cg->serv->uin);
+        fprintf (stf, "server %s %ld\n", ConnectionServerType (cg->serv), cg->serv->uin);
         fprintf (stf, "label %s\n", s_quote (cg->name));
         fprintf (stf, "id %d\n", cg->id);
         fprintf (stf, "%s", OptString (&cg->copts));
@@ -1627,14 +1649,13 @@ int PrefWriteConfFile (void)
             continue;
         if ((!ss->uin && ss->type == TYPE_SERVER)
             || (ss->type != TYPE_SERVER && ss->type != TYPE_SERVER_OLD
+                && ss->type != TYPE_MSN_SERVER
                 && ss->type != TYPE_MSGLISTEN && ss->type != TYPE_REMOTE)
             || (ss->type == TYPE_MSGLISTEN && ss->parent && !ss->parent->uin))
             continue;
 
         fprintf (rcf, "[Connection]\n");
-        fprintf (rcf, "type %s%s\n",  ss->type == TYPE_SERVER     ? "icq8" :
-                                      ss->type == TYPE_SERVER_OLD ? "icq5" :
-                                      ss->type == TYPE_MSGLISTEN  ? "peer" : "remote",
+        fprintf (rcf, "type %s%s\n",  ConnectionServerType (ss),
                                       ss->flags & CONN_AUTOLOGIN ? " auto" : "");
         fprintf (rcf, "version %d\n", ss->version);
         if (ss->pref_server)
@@ -1643,6 +1664,8 @@ int PrefWriteConfFile (void)
             fprintf (rcf, "port %ld\n",    ss->pref_port);
         if (ss->uin)
             fprintf (rcf, "uin %ld\n",     ss->uin);
+        if (ss->screen && ss->type == TYPE_MSN_SERVER)
+            fprintf (rcf, "screen %s\n",   s_quote (ss->screen));
         if (ss->pref_passwd)
             fprintf (rcf, "password %s\n", s_quote (ss->pref_passwd));
         else if (!k)
