@@ -27,7 +27,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: oldicq_client.c,v 1.5 2005/03/10 18:41:33 kuhlmann Exp $
+ * $Id: oldicq_client.c,v 1.6 2005/12/22 16:33:17 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -69,7 +69,7 @@ void CmdPktCmdSendMessage (Connection *conn, Contact *cont, const char *text, UD
     if (!cont)
         return;
     
-    IMIntMsg (cont, conn, NOW, STATUS_OFFLINE, INT_MSGACK_V5, text, NULL);
+    IMIntMsg (cont, conn, NOW, STATUS_ICQOFFLINE, INT_MSGACK_V5, text, NULL);
                     
     pak = PacketCv5 (conn, CMD_SEND_MESSAGE);
     PacketWrite4    (pak, cont->uin);
