@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: oscar_base.c,v 1.7 2005/04/18 18:16:51 kuhlmann Exp $
+ * $Id: oscar_base.c,v 1.11 2005/12/22 20:24:57 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -90,6 +90,9 @@ void SrvCallBackFlap (Event *event)
             FlapChannel4 (conn, event->pak);
             break;
         case 5: /* Ping */
+            if (PacketReadB4 (event->pak) || PacketReadLeft (event->pak))
+                FlapPrint (event->pak);
+            break;
         default:
             rl_printf (i18n (1884, "FLAP with unknown channel %ld received.\n"), event->pak->cmd);
     }
@@ -395,7 +398,7 @@ Event *ConnectionInitServer (Connection *conn)
     conn->reconnect= &SrvCallBackReconn;
     conn->close    = &FlapCliGoodbye;
     s_repl (&conn->server, conn->pref_server);
-    if (conn->status == STATUS_OFFLINE)
+    if (conn->status == STATUS_ICQOFFLINE)
         conn->status = conn->pref_status;
     
     if ((event = QueueDequeue2 (conn, QUEUE_DEP_OSCARLOGIN, 0, NULL)))
@@ -449,7 +452,7 @@ static void SrvCallBackReconn (Connection *conn)
         EventD (event);
     }
     for (i = 0; (cont = ContactIndex (cg, i)); i++)
-        cont->status = STATUS_OFFLINE;
+        cont->status = STATUS_ICQOFFLINE;
 }
 
 static void SrvCallBackDoReconn (Event *event)
@@ -595,7 +598,7 @@ Connection *SrvRegisterUIN (Connection *conn, const char *pass)
         new->flags   = conn->flags & ~CONN_CONFIGURED;
         new->version = conn->version;
         new->uin     = 0;
-        new->pref_status  = STATUS_ONLINE;
+        new->pref_status  = STATUS_ICQONLINE;
         new->pref_server  = strdup (conn->pref_server);
         new->pref_port    = conn->pref_port;
         new->pref_passwd  = strdup (pass);
@@ -604,12 +607,13 @@ Connection *SrvRegisterUIN (Connection *conn, const char *pass)
     {
         new->version = 8;
         new->uin     = 0;
-        new->pref_status  = STATUS_ONLINE;
+        new->pref_status  = STATUS_ICQONLINE;
         new->pref_server  = strdup ("login.icq.com");
         new->pref_port    = 5190;
         new->pref_passwd  = strdup (pass);
         new->flags |= CONN_AUTOLOGIN;
     }
+    s_repl (&new->screen, "0");
     new->server = strdup (new->pref_server);
     new->port = new->pref_port;
     new->passwd = strdup (pass);
