@@ -27,7 +27,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: oscar_icbm.c,v 1.24 2005/06/04 20:53:26 kuhlmann Exp $
+ * $Id: oscar_icbm.c,v 1.28 2005/12/22 16:33:18 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -54,6 +54,7 @@ static void SnacCallbackType2Ack (Event *event);
 static void SnacCallbackType2 (Event *event);
 static void SnacCallbackIgnore (Event *event);
 
+#define PEEK_REFID 0x3d1db11f
 
 /*
  * SRV_ICBMERR - SNAC(4,1)
@@ -63,7 +64,7 @@ JUMP_SNAC_F(SnacSrvIcbmerr)
     Connection *serv = event->conn;
     UWORD err = PacketReadB2 (event->pak);
 
-    if ((event->pak->ref & 0xffff) == 0x1771 && (err == 0xe || err == 4 || err == 9))
+    if ((event->pak->ref == PEEK_REFID) && (err == 0xe || err == 4 || err == 9))
     {
         if (err == 0xe || err == 9)
             rl_print (i18n (2017, "The user is online, but possibly invisible.\n"));
@@ -168,7 +169,7 @@ JUMP_SNAC_F(SnacSrvAckmsg)
         const char *opt_text;
         if (OptGetStr (event->opt, CO_MSGTEXT, &opt_text));
         {
-            IMIntMsg (cont, serv, NOW, STATUS_OFFLINE, INT_MSGACK_TYPE2, opt_text, NULL);
+            IMIntMsg (cont, serv, NOW, STATUS_ICQOFFLINE, INT_MSGACK_TYPE2, opt_text, NULL);
             if ((~cont->oldflags & CONT_SEENAUTO) && strlen (text) && strcmp (text, opt_text))
             {
                 IMSrvMsg (cont, serv, NOW, OptSetVals (NULL, CO_ORIGIN, CV_ORIGIN_v8,
@@ -243,9 +244,10 @@ UBYTE SnacCliSendmsg (Connection *serv, Contact *cont, const char *text, UDWORD
             
             remenc = ContactPrefVal (cont, CO_ENCODING);
             
-            if (cont->status != STATUS_OFFLINE &&
-                HAS_CAP (cont->caps, CAP_UTF8) && cont->dc && cont->dc->version >= 7
-                && !(cont->dc->id1 == (time_t)0xffffff42 && (cont->dc->id2 & 0x7fffffff) < (time_t)0x00040a03)) /* exclude old mICQ */
+            if (cont->status != STATUS_ICQOFFLINE &&
+                HAS_CAP (cont->caps, CAP_UTF8) &&
+                !(cont->dc && cont->dc->id1 == (time_t)0xffffff42 &&
+                  (cont->dc->id2 & 0x7fffffff) < (time_t)0x00040c00)) /* exclude old mICQ */
             {
                 enc = ENC_UCS2BE;
                 icqenc = 2;
@@ -362,7 +364,7 @@ static void SnacCallbackType2 (Event *event)
         if (serv->connect & CONNECT_OK)
         {
             if (event->attempts > 1)
-                IMIntMsg (cont, serv, NOW, STATUS_OFFLINE, INT_MSGTRY_TYPE2,
+                IMIntMsg (cont, serv, NOW, STATUS_ICQOFFLINE, INT_MSGTRY_TYPE2,
                           opt_text, NULL);
             SnacSend (serv, PacketClone (pak));
             event->attempts++;
@@ -407,10 +409,9 @@ UBYTE SnacCliSendmsg2 (Connection *serv, Contact *cont, Opt *opt)
     if (opt_type == MSG_GET_PEEK)
     {
         peek = 1;
-        opt_type = MSG_GET_AWAY;
+        opt_type = MSG_GET_AWAY | MSGF_GETAUTO;
     }
     
-    
     if (!cont || !(peek || (opt_type & 0xff) == MSG_GET_VER || opt_force ||
         (HAS_CAP (cont->caps, CAP_SRVRELAY) && HAS_CAP (cont->caps, CAP_ISICQ))))
         return RET_DEFER;
@@ -432,7 +433,7 @@ UBYTE SnacCliSendmsg2 (Connection *serv, Contact *cont, Opt *opt)
     
     OptSetVal (opt, CO_MSGTRANS, opt_trans &= ~CV_MSGTRANS_TYPE2);
 
-    pak = SnacC (serv, 4, 6, 0, peek ? 0x1771 : 0);
+    pak = SnacC (serv, 4, 6, 0, peek ? PEEK_REFID : 0);
     PacketWriteB4 (pak, mtime);
     PacketWriteB4 (pak, mid);
     PacketWriteB2 (pak, 2);
@@ -446,6 +447,7 @@ UBYTE SnacCliSendmsg2 (Connection *serv, Contact *cont, Opt *opt)
      PacketWriteCapID   (pak, peek ? CAP_NONE : CAP_SRVRELAY);
      PacketWriteTLV2    (pak, 10, 1);
      PacketWriteB4      (pak, 0x000f0000); /* empty TLV(15) */
+     if (!peek) {
      PacketWriteTLV     (pak, 10001);
       PacketWriteLen     (pak);
        PacketWrite2       (pak, serv->assoc && serv->assoc->connect & CONNECT_OK
@@ -454,16 +456,33 @@ UBYTE SnacCliSendmsg2 (Connection *serv, Contact *cont, Opt *opt)
        PacketWrite2       (pak, 0);
        PacketWrite4       (pak, 3);
        PacketWrite1       (pak, 0);
-       PacketWrite2       (pak, serv->our_seq_dc);
+       PacketWrite2       (pak, peek ? 0 : serv->our_seq_dc);
       PacketWriteLenDone (pak);
-      SrvMsgAdvanced     (pak, serv->our_seq_dc, opt_type, serv->status, cont->status, -1, c_out_for (opt_text, cont, opt_type));
-      PacketWrite4       (pak, TCP_COL_FG);
-      PacketWrite4       (pak, TCP_COL_BG);
-      if (CONT_UTF8 (cont, opt_type))
-          PacketWriteDLStr     (pak, CAP_GID_UTF8);
+      if (peek)
+      {
+          PacketWriteLen    (pak);
+           PacketWrite2      (pak, serv->our_seq_dc);       /* sequence number */
+           PacketWrite4      (pak, 0);
+           PacketWrite4      (pak, 0);
+           PacketWrite4      (pak, 0);
+          PacketWriteLenDone (pak);
+          PacketWrite2      (pak, MSG_GET_DND | MSGF_GETAUTO);    /* message type    */
+          PacketWrite2      (pak, 0);     /* status          */
+          PacketWrite2      (pak, 0);      /* flags           */
+          PacketWrite2      (pak, 0x7fff);
+          PacketWrite1      (pak, 0);
+      }
+      else
+      {
+          SrvMsgAdvanced     (pak, serv->our_seq_dc, opt_type, serv->status, cont->status, -1, c_out_for (opt_text, cont, opt_type));
+          PacketWrite4       (pak, TCP_COL_FG);
+          PacketWrite4       (pak, TCP_COL_BG);
+          if (CONT_UTF8 (cont, opt_type))
+              PacketWriteDLStr     (pak, CAP_GID_UTF8);
+      }
      PacketWriteTLVDone (pak);
+     }
     PacketWriteTLVDone (pak);
-    PacketWriteB4      (pak, 0x00030000); /* empty TLV(3) */
     
     if (peek)
     {    
@@ -473,6 +492,7 @@ UBYTE SnacCliSendmsg2 (Connection *serv, Contact *cont, Opt *opt)
     }
     else
     {
+        PacketWriteB4      (pak, 0x00030000); /* empty TLV(3) */
         QueueEnqueueData (serv, QUEUE_TYPE2_RESEND, serv->our_seq_dc,
                           time (NULL), pak, cont, opt, &SnacCallbackType2);
     }
@@ -772,16 +792,16 @@ JUMP_SNAC_F(SnacSrvSrvackmsg)
         case 1:
             event2 = QueueDequeue (serv, QUEUE_TYPE1_RESEND_ACK, pak->ref);
             if (event2 && OptGetStr (event2->opt, CO_MSGTEXT, &text))
-                IMIntMsg (cont, serv, NOW, STATUS_OFFLINE, INT_MSGACK_V8, text, NULL);
+                IMIntMsg (cont, serv, NOW, STATUS_ICQOFFLINE, INT_MSGACK_V8, text, NULL);
             break;
         case 4:
             event2 = QueueDequeue (serv, QUEUE_TYPE4_RESEND_ACK, pak->ref);
             if (event2 && OptGetStr (event2->opt, CO_MSGTEXT, &text))
-                IMIntMsg (cont, serv, NOW, STATUS_OFFLINE, INT_MSGACK_V8, text, NULL);
+                IMIntMsg (cont, serv, NOW, STATUS_ICQOFFLINE, INT_MSGACK_V8, text, NULL);
             break;
         case 2: /* msg was received by server */
             event2 = QueueDequeue (serv, QUEUE_TYPE2_RESEND_ACK, pak->ref);
-            if ((pak->ref & 0xffff) == 0x1771)
+            if (pak->ref == PEEK_REFID)
             {
                 rl_print (i18n (2573, "The user is probably offline.\n"));
                 return;
@@ -796,22 +816,22 @@ void SrvMsgAdvanced (Packet *pak, UDWORD seq, UWORD msgtype, UWORD status,
                      UDWORD deststatus, UWORD flags, const char *msg)
 {
     if (msgtype == MSG_SSL_OPEN)       status = 0;
-    else if (status == (UWORD)STATUS_OFFLINE) /* keep */ ;
-    else if (status & STATUSF_DND)     status = STATUSF_DND  | (status & STATUSF_INV);
-    else if (status & STATUSF_OCC)     status = STATUSF_OCC  | (status & STATUSF_INV);
-    else if (status & STATUSF_NA)      status = STATUSF_NA   | (status & STATUSF_INV);
-    else if (status & STATUSF_AWAY)    status = STATUSF_AWAY | (status & STATUSF_INV);
-    else if (status & STATUSF_FFC)     status = STATUSF_FFC  | (status & STATUSF_INV);
-    else                               status &= STATUSF_INV;
+    else if (status == (UWORD)STATUS_ICQOFFLINE) /* keep */ ;
+    else if (status & STATUSF_ICQDND)     status = STATUSF_ICQDND  | (status & STATUSF_ICQINV);
+    else if (status & STATUSF_ICQOCC)     status = STATUSF_ICQOCC  | (status & STATUSF_ICQINV);
+    else if (status & STATUSF_ICQNA)      status = STATUSF_ICQNA   | (status & STATUSF_ICQINV);
+    else if (status & STATUSF_ICQAWAY)    status = STATUSF_ICQAWAY | (status & STATUSF_ICQINV);
+    else if (status & STATUSF_ICQFFC)     status = STATUSF_ICQFFC  | (status & STATUSF_ICQINV);
+    else                                  status &= STATUSF_ICQINV;
     
     if      (flags != (UWORD)-1)           /* keep */ ;
-    else if (deststatus == (UWORD)STATUS_OFFLINE) /* keep */ ;
-    else if (deststatus & STATUSF_DND)     flags = TCP_MSGF_CLIST;
-    else if (deststatus & STATUSF_OCC)     flags = TCP_MSGF_CLIST;
-    else if (deststatus & STATUSF_NA)      flags = TCP_MSGF_1;
-    else if (deststatus & STATUSF_AWAY)    flags = TCP_MSGF_1;
-    else if (deststatus & STATUSF_FFC)     flags = TCP_MSGF_LIST | TCP_MSGF_1;
-    else                                   flags = TCP_MSGF_LIST | TCP_MSGF_1;
+    else if (deststatus == (UWORD)STATUS_ICQOFFLINE) /* keep */ ;
+    else if (deststatus & STATUSF_ICQDND)     flags = TCP_MSGF_CLIST;
+    else if (deststatus & STATUSF_ICQOCC)     flags = TCP_MSGF_CLIST;
+    else if (deststatus & STATUSF_ICQNA)      flags = TCP_MSGF_1;
+    else if (deststatus & STATUSF_ICQAWAY)    flags = TCP_MSGF_1;
+    else if (deststatus & STATUSF_ICQFFC)     flags = TCP_MSGF_LIST | TCP_MSGF_1;
+    else                                      flags = TCP_MSGF_LIST | TCP_MSGF_1;
 
     PacketWriteLen    (pak);
      PacketWrite2      (pak, seq);       /* sequence number */
@@ -922,29 +942,29 @@ void SrvReceiveAdvanced (Connection *serv, Event *inc_event, Packet *inc_pak, Ev
     
     accept = FALSE;
 
-    if      (serv->status & STATUSF_DND)
+    if      (serv->status & STATUSF_ICQDND)
         ack_msg = (tauto = ContactPrefStr (cont, CO_TAUTODND))  && *tauto ? tauto : ContactPrefStr (cont, CO_AUTODND);
-    else if (serv->status & STATUSF_OCC)
+    else if (serv->status & STATUSF_ICQOCC)
         ack_msg = (tauto = ContactPrefStr (cont, CO_TAUTOOCC))  && *tauto ? tauto : ContactPrefStr (cont, CO_AUTOOCC);
-    else if (serv->status & STATUSF_NA)
+    else if (serv->status & STATUSF_ICQNA)
         ack_msg = (tauto = ContactPrefStr (cont, CO_TAUTONA))   && *tauto ? tauto : ContactPrefStr (cont, CO_AUTONA);
-    else if (serv->status & STATUSF_AWAY)
+    else if (serv->status & STATUSF_ICQAWAY)
         ack_msg = (tauto = ContactPrefStr (cont, CO_TAUTOAWAY)) && *tauto ? tauto : ContactPrefStr (cont, CO_AUTOAWAY);
     else
         ack_msg = "";
 
-/*  if (serv->status & STATUSF_DND)  ack_status  = pri & 4 ? TCP_ACK_ONLINE : TCP_ACK_DND; else
+/*  if (serv->status & STATUSF_ICQDND)  ack_status  = pri & 4 ? TCP_ACK_ONLINE : TCP_ACK_DND; else
  *
  * Don't refuse until we have sensible preferences for that
  */
-    if (serv->status & STATUSF_DND)  ack_status  = TCP_ACK_ONLINE; else
-    if (serv->status & STATUSF_OCC)  ack_status  = TCP_ACK_ONLINE; else
-    if (serv->status & STATUSF_NA)   ack_status  = TCP_ACK_NA;     else
-    if (serv->status & STATUSF_AWAY) ack_status  = TCP_ACK_AWAY;
-    else                             ack_status  = TCP_ACK_ONLINE;
+    if (serv->status & STATUSF_ICQDND)  ack_status  = TCP_ACK_ONLINE; else
+    if (serv->status & STATUSF_ICQOCC)  ack_status  = TCP_ACK_ONLINE; else
+    if (serv->status & STATUSF_ICQNA)   ack_status  = TCP_ACK_NA;     else
+    if (serv->status & STATUSF_ICQAWAY) ack_status  = TCP_ACK_AWAY;
+    else                                ack_status  = TCP_ACK_ONLINE;
 
     ack_flags = 0;
-    if (serv->status & STATUSF_INV)  ack_flags |= TCP_MSGF_INV;
+    if (serv->status & STATUSF_ICQINV)  ack_flags |= TCP_MSGF_INV;
 
     switch (msgtype & ~MSGF_MASS)
     {
