@@ -30,7 +30,7 @@
  * As a special exemption, you may link your binary against OpenSSL,
  * provided your operating system distribution doesn't ship libgnutls.
  *
- * $Id: oscar_roster.c,v 1.22 2005/05/17 21:02:56 kuhlmann Exp $
+ * $Id: oscar_roster.c,v 1.25 2005/12/23 02:34:11 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -327,10 +327,7 @@ void SnacCliRosterbulkadd (Connection *serv, ContactGroup *cs)
     for (i = 0; (cont = ContactIndex (cs, i)); i++)
     {
         if (cont->group && cont->group->serv && !ContactGroupPrefVal (cont->group, CO_ISSBL))
-        {
             SnacCliRosteradd (serv, cont->group, NULL);
-            OptSetVal (&cont->group->copts, CO_ISSBL, 1);
-        }
     }
     
     SnacCliAddstart (serv);
@@ -394,10 +391,7 @@ void SnacCliRosteradd (Connection *serv, ContactGroup *cg, Contact *cont)
         UWORD type = 0;
         
         if (!ContactGroupPrefVal (cg, CO_ISSBL))
-        {
             SnacCliRosteradd (serv, cg, NULL);
-            OptSetVal (&cg->copts, CO_ISSBL, 1);
-        }
         
         SnacCliAddstart (serv);
 
@@ -442,6 +436,7 @@ void SnacCliRosteradd (Connection *serv, ContactGroup *cg, Contact *cont)
         PacketWriteBLen     (pak);
         PacketWriteBLenDone (pak);
         SnacSend (serv, pak);
+        OptSetVal (&cg->copts, CO_ISSBL, 1);
     }
 }
 
@@ -569,7 +564,7 @@ void SnacCliRosterdeletecontact (Connection *serv, Contact *cont)
     SnacCliAddstart (serv);
     pak = SnacC (serv, 19, 10, 0, 0);
 
-    if ((ids = ContactID (cont, ROSTER_TYPE_NORMAL)) && ids->issbl)
+    if ((ids = ContactIDHas (cont, ROSTER_TYPE_NORMAL)) && ids->issbl)
     {
         PacketWriteStrB     (pak, s_sprintf ("%ld", cont->uin));
         PacketWriteB2       (pak, ids->tag);
@@ -578,11 +573,11 @@ void SnacCliRosterdeletecontact (Connection *serv, Contact *cont)
         PacketWriteBLen     (pak);
         PacketWriteBLenDone (pak);
     }
-    if ((ids = ContactID (cont, ROSTER_TYPE_INVISIBLE)) && ids->issbl)
+    if ((ids = ContactIDHas (cont, ROSTER_TYPE_INVISIBLE)) && ids->issbl)
         SnacCliRosterbulkone (serv, cont, pak, ROSTER_TYPE_INVISIBLE);
-    if ((ids = ContactID (cont, ROSTER_TYPE_VISIBLE)) && ids->issbl)
+    if ((ids = ContactIDHas (cont, ROSTER_TYPE_VISIBLE)) && ids->issbl)
         SnacCliRosterbulkone (serv, cont, pak, ROSTER_TYPE_VISIBLE);
-    if ((ids = ContactID (cont, ROSTER_TYPE_IGNORE)) && ids->issbl)
+    if ((ids = ContactIDHas (cont, ROSTER_TYPE_IGNORE)) && ids->issbl)
         SnacCliRosterbulkone (serv, cont, pak, ROSTER_TYPE_IGNORE);
 
     SnacSend (serv, pak);
@@ -622,11 +617,13 @@ JUMP_SNAC_F(SnacSrvUpdateack)
     Event *event2;
     UWORD err;
     
-    while (PacketReadLeft (event->pak))
+    if (PacketReadLeft (event->pak))
     {
+        err = PacketReadB2 (event->pak);
+        SnacSrvUpdateack (event);
+
         event2 = QueueDequeue (serv, QUEUE_CHANGE_ROSTER, event->pak->ref);
         cont = event2 ? event2->cont : NULL;
-        err = PacketReadB2 (event->pak);
         
         switch (err)
         {
