@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: peer_file.c,v 1.71 2005/05/06 21:40:47 kuhlmann Exp $
+ * $Id: peer_file.c,v 1.72 2005/12/22 16:33:18 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -169,7 +169,7 @@ UBYTE PeerFileIncAccept (Connection *list, Event *event)
         opt = OptSetVals (NULL, CO_MSGTEXT, opt_files, 0);
         if (!OptGetStr (event->wait->opt, CO_REFUSE, &txt))
             txt = "";
-        IMIntMsg (cont, serv, NOW, STATUS_OFFLINE, INT_FILE_REJING, txt, opt);
+        IMIntMsg (cont, serv, NOW, STATUS_ICQOFFLINE, INT_FILE_REJING, txt, opt);
         return FALSE;
     }
     ASSERT_FILELISTEN (flist);
@@ -187,7 +187,7 @@ UBYTE PeerFileIncAccept (Connection *list, Event *event)
     fpeer->reconnect = &TCPDispatchReconn;
 
     opt = OptSetVals (NULL, CO_BYTES, opt_bytes, CO_MSGTEXT, opt_files, 0);
-    IMIntMsg (cont, serv, NOW, STATUS_OFFLINE, INT_FILE_ACKING, "", opt);
+    IMIntMsg (cont, serv, NOW, STATUS_ICQOFFLINE, INT_FILE_ACKING, "", opt);
     
     return TRUE;
 }
