@@ -28,7 +28,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: preferences.c,v 1.49 2005/05/07 11:05:40 kuhlmann Exp $
+ * $Id: preferences.c,v 1.51 2005/12/20 21:04:47 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -48,6 +48,7 @@
 #endif
 #include "file_util.h"
 #include "preferences.h"
+#include "connection.h"
 #include "util_ui.h"
 #include "conv.h"
 #include "contact.h"
@@ -93,7 +94,7 @@ const char *PrefDefUserDirReal (Preferences *pref)
         if (!home || !*home)
 #endif
         home = getenv ("HOME");
-#if HAVE_GETPWUID && HAVE_GETUID
+#if HAVE_GETPWUID && HAVE_GETUID && !__AMIGA__
         if ((!home || !*home) && pwd && pwd->pw_dir)
             home = pwd->pw_dir;
 #endif
@@ -199,6 +200,7 @@ static FILE *PrefOpenStat (Preferences *pref)
 BOOL PrefLoad (Preferences *pref)
 {
     FILE *rcf, *stf;
+    Connection *conn;
     Contact *cont;
     int i;
     BOOL ok = TRUE;
@@ -233,6 +235,13 @@ BOOL PrefLoad (Preferences *pref)
             if (0)
         case 2:
             pref->enc_loc = ENC_AUTO;
+        case 3:
+            for (i = 0; (conn = ConnectionNr (i)); i++)
+            {
+                cont = ContactFind (conn->contacts, 0, 82274703, NULL);
+                if (cont)
+                    OptSetVal (&cont->copts, CO_WANTSBL, 0);
+            }
         case AUTOUPDATE_CURRENT:
         default:
             pref->autoupdate = AUTOUPDATE_CURRENT;
