@@ -5,7 +5,7 @@
  *  Lots of changes from Rüdiger Kuhlmann. File transfer by Rüdiger Kuhlmann.
  *  This file may be distributed under version 2 of the GPL licence.
  *
- * $Id: tcp.c,v 1.202 2005/03/31 17:28:15 kuhlmann Exp $
+ * $Id: tcp.c,v 1.203 2005/12/22 16:33:18 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -1498,7 +1498,7 @@ static void TCPCallBackResend (Event *event)
         if (peer->connect & CONNECT_OK)
         {
             if (event->attempts > 1)
-                IMIntMsg (cont, peer->parent->parent, NOW, STATUS_OFFLINE, INT_MSGTRY_DC, opt_text, NULL);
+                IMIntMsg (cont, peer->parent->parent, NOW, STATUS_ICQOFFLINE, INT_MSGTRY_DC, opt_text, NULL);
 
             if (event->attempts < 2)
                 PeerPacketSend (peer, pak);
@@ -1622,7 +1622,7 @@ static void TCPCallBackReceive (Event *event)
             {
                 case MSG_NORM:
                 case MSG_URL:
-                    IMIntMsg (cont, peer, NOW, STATUS_OFFLINE, opt_origin == CV_ORIGIN_dc ? INT_MSGACK_DC : INT_MSGACK_SSL, opt_text, NULL);
+                    IMIntMsg (cont, peer, NOW, STATUS_ICQOFFLINE, opt_origin == CV_ORIGIN_dc ? INT_MSGACK_DC : INT_MSGACK_SSL, opt_text, NULL);
                     if (~cont->oldflags & CONT_SEENAUTO && strlen (tmp) && strcmp (tmp, opt_text))
                     {
                         IMSrvMsg (cont, serv, NOW, OptSetVals (NULL, CO_ORIGIN, opt_origin, CO_MSGTYPE, MSG_AUTO, CO_MSGTEXT, tmp, 0));
