@@ -3,14 +3,11 @@
  *
  * Copyright: This file may be distributed under version 2 of the GPL licence.
  *
- * $Id: util_io.c,v 1.64.2.12 2003/10/06 18:37:23 kuhlmann Exp $
+ * $Id: util_io.c,v 1.83 2005/02/27 19:27:01 kuhlmann Exp $
  */
 
 #include "micq.h"
-#include <stdlib.h>
-#include <stdio.h>
 #include <errno.h>
-#include <string.h>
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -40,6 +37,12 @@
 #if HAVE_WINSOCK2_H
 #include <winsock2.h>
 #endif
+#if HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
 #if !HAVE_DECL_H_ERRNO
 extern int h_errno;
 #endif
@@ -48,12 +51,11 @@ extern int h_errno;
 #include "preferences.h"
 #include "util_ui.h"
 #include "util_io.h"
-#include "util_str.h"
 #include "util_ssl.h"
 #include "conv.h"
 #include "util.h"
 #include "contact.h"
-#include "session.h"
+#include "connection.h"
 #include "packet.h"
 
 #ifndef HAVE_HSTRERROR
@@ -101,14 +103,14 @@ void UtilIOConnectUDP (Connection *conn)
     {
         if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
         {
-            M_print (i18n (1055, "Socket creation failed"));
-            M_print (".\n");
+            rl_print (i18n (1055, "Socket creation failed"));
+            rl_print (".\n");
         }
         conn->sok = -1;
         return;
     }
     if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-        M_print (i18n (1056, "Socket created, attempting to connect.\n"));
+        rl_print (i18n (1056, "Socket created, attempting to connect.\n"));
 
     if (prG->s5Use)
     {
@@ -119,7 +121,7 @@ void UtilIOConnectUDP (Connection *conn)
         if (bind (conn->sok, (struct sockaddr *) &sin, sizeof (struct sockaddr)) < 0)
         {
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-                M_print (i18n (1637, "Can't bind socket to free port\n"));
+                rl_print (i18n (1637, "Can't bind socket to free port\n"));
             conn->sok = -1;
             return;
         }
@@ -136,8 +138,8 @@ void UtilIOConnectUDP (Connection *conn)
             {
                 if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
                 {
-                    M_printf (i18n (1596, "[SOCKS] Can't find hostname %s: %s."), prG->s5Host, hstrerror (h_errno));
-                    M_print ("\n");
+                    rl_printf (i18n (1596, "[SOCKS] Can't find hostname %s: %s."), prG->s5Host, hstrerror (h_errno));
+                    rl_print ("\n");
                 }
                 conn->sok = -1;
                 return;
@@ -150,7 +152,7 @@ void UtilIOConnectUDP (Connection *conn)
         if (s5Sok < 0)
         {
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-                M_print (i18n (1597, "[SOCKS] Socket creation failed\n"));
+                rl_print (i18n (1597, "[SOCKS] Socket creation failed\n"));
             conn->sok = -1;
             return;
         }
@@ -159,8 +161,8 @@ void UtilIOConnectUDP (Connection *conn)
         {
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
             {
-                M_print (i18n (1598, "[SOCKS] Connection request refused"));
-                M_print (".\n");
+                rl_print (i18n (1598, "[SOCKS] Connection request refused"));
+                rl_print (".\n");
             }
             conn->sok = -1;
             return;
@@ -179,8 +181,8 @@ void UtilIOConnectUDP (Connection *conn)
             {
                 if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
                 {
-                    M_print (i18n (1599, "[SOCKS] Authentication method incorrect"));
-                    M_print (".\n");
+                    rl_print (i18n (1599, "[SOCKS] Authentication method incorrect"));
+                    rl_print (".\n");
                 }
                 sockclose (s5Sok);
                 conn->sok = -1;
@@ -197,8 +199,8 @@ void UtilIOConnectUDP (Connection *conn)
             {
                 if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
                 {
-                    M_print (i18n (1600, "[SOCKS] Authorization failure"));
-                    M_print (".\n");
+                    rl_print (i18n (1600, "[SOCKS] Authorization failure"));
+                    rl_print (".\n");
                 }
                 sockclose (s5Sok);
                 conn->sok = -1;
@@ -211,8 +213,8 @@ void UtilIOConnectUDP (Connection *conn)
             {
                 if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
                 {
-                    M_print (i18n (1599, "[SOCKS] Authentication method incorrect"));
-                    M_print (".\n");
+                    rl_print (i18n (1599, "[SOCKS] Authentication method incorrect"));
+                    rl_print (".\n");
                 }
                 sockclose (s5Sok);
                 conn->sok = -1;
@@ -235,8 +237,8 @@ void UtilIOConnectUDP (Connection *conn)
         {
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
             {
-                M_print (i18n (1601, "[SOCKS] General SOCKS server failure"));
-                M_print (".\n");
+                rl_print (i18n (1601, "[SOCKS] General SOCKS server failure"));
+                rl_print (".\n");
             }
             sockclose (s5Sok);
             conn->sok = -1;
@@ -245,15 +247,15 @@ void UtilIOConnectUDP (Connection *conn)
     }
 
     sin.sin_addr.s_addr = inet_addr (conn->server);
-    if (sin.sin_addr.s_addr == -1)      /* name isn't n.n.n.n so must be DNS */
+    if (sin.sin_addr.s_addr + 1 == 0)      /* name isn't n.n.n.n so must be DNS */
     {
         host_struct = gethostbyname (conn->server);
         if (!host_struct)
         {
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
             {
-                M_printf (i18n (1948, "Can't find hostname %s: %s."), conn->server, hstrerror (h_errno));
-                M_print ("\n");
+                rl_printf (i18n (1948, "Can't find hostname %s: %s."), conn->server, hstrerror (h_errno));
+                rl_print ("\n");
             }
             conn->sok = -1;
             return;
@@ -277,7 +279,7 @@ void UtilIOConnectUDP (Connection *conn)
     if (conct == -1)            /* did we connect ? */
     {
         if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-            M_printf (i18n (1966, " Connection refused on port %ld at %s\n"), conn->port, conn->server);
+            rl_printf (i18n (1966, " Connection refused on port %ld at %s\n"), conn->port, conn->server);
         conn->sok = -1;
         return;
     }
@@ -287,7 +289,7 @@ void UtilIOConnectUDP (Connection *conn)
     conn->our_local_ip = ntohl (sin.sin_addr.s_addr);
 
     if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-        M_printf (i18n (1053, "Connected to %s, waiting for response\n"), conn->server);
+        rl_printf (i18n (1053, "Connected to %s, waiting for response\n"), conn->server);
 }
 
 #ifdef __AMIGA__
@@ -297,7 +299,7 @@ void UtilIOConnectUDP (Connection *conn)
 #endif
 #define CONN_FAIL(s)  { const char *t = s;      \
                         if (t) if (prG->verbose || conn->type & TYPEF_ANY_SERVER) \
-                            M_printf    ("%s [%d]\n", t, __LINE__);  \
+                            rl_printf    ("%s [%d]\n", t, __LINE__);  \
                         EventD (QueueDequeue (conn, QUEUE_CON_TIMEOUT, conn->ip)); \
                         if (conn->sok > 0)          \
                           sockclose (conn->sok);     \
@@ -308,7 +310,7 @@ void UtilIOConnectUDP (Connection *conn)
                         return; }
 #define CONN_FAIL_RC(s) { int rc = errno;                  \
                           if (prG->verbose || conn->type & TYPEF_ANY_SERVER) \
-                          M_print (i18n (1949, "failed:\n"));\
+                          rl_print (i18n (1949, "failed:\n"));\
                           CONN_FAIL (s_sprintf  ("%s: %s (%d).", s, strerror (rc), rc)) }
 #define CONN_CHECK(s) { if (rc == -1) { rc = errno;            \
                           if (rc == EAGAIN) return;             \
@@ -326,7 +328,8 @@ void UtilIOConnectUDP (Connection *conn)
  * Usage: conn->dispatch will be called with conn->connect++ if ok,
  * conn->connect+=2 if fail.
  */
-void UtilIOConnectTCP (Connection *conn)
+#undef UtilIOConnectTCP
+void UtilIOConnectTCP (Connection *conn DEBUGPARAM)
 {
     int rc, rce;
     socklen_t length;
@@ -370,7 +373,7 @@ void UtilIOConnectTCP (Connection *conn)
 
         if (conn->server)
             conn->ip = htonl (inet_addr (conn->server));
-        if (conn->ip == -1 && conn->server)
+        if (conn->ip + 1 == 0 && conn->server)
         {
             host = gethostbyname (conn->server);
             if (!host)
@@ -401,15 +404,15 @@ void UtilIOConnectTCP (Connection *conn)
 
         if (rc >= 0)
         {
-            M_print ("");
+            rl_print ("");
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-                if (M_pos () > 0)
-                     M_print (i18n (1634, "ok.\n"));
+                if (rl_pos () > 0)
+                     rl_print (i18n (1634, "ok.\n"));
             if (prG->s5Use)
             {
                 QueueEnqueueData (conn, QUEUE_CON_TIMEOUT, conn->ip,
-                                  time (NULL) + 10,
-                                  NULL, conn->uin, NULL, &UtilIOTOConn);
+                                  time (NULL) + 10, NULL,
+                                  conn->cont, NULL, &UtilIOTOConn);
                 conn->dispatch = &UtilIOConnectCallback;
                 conn->connect |= CONNECT_SOCKS_ADD;
                 UtilIOConnectCallback (conn);
@@ -429,13 +432,13 @@ void UtilIOConnectTCP (Connection *conn)
         if (0)
 #endif
         {
-            M_print ("");
+            rl_print ("");
             if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
-                if (M_pos () > 0)
-                    M_print ("\n");
+                if (rl_pos () > 0)
+                    rl_print ("\n");
             QueueEnqueueData (conn, QUEUE_CON_TIMEOUT, conn->ip,
-                              time (NULL) + 10,
-                              NULL, conn->uin, NULL, &UtilIOTOConn);
+                              time (NULL) + 10, NULL,
+                              conn->cont, NULL, &UtilIOTOConn);
             conn->utilio   = conn->dispatch;
             conn->dispatch = &UtilIOConnectCallback;
             conn->connect |= CONNECT_SELECT_W | CONNECT_SELECT_X;
@@ -480,16 +483,16 @@ void UtilIOConnectTCP (Connection *conn)
         conn->port = ntohs (sin.sin_port);
         s_repl (&conn->server, "localhost");
         if (prG->verbose || conn->type == TYPE_MSGLISTEN)
-            if (M_pos () > 0)
-                M_print (i18n (1634, "ok.\n"));
+            if (rl_pos () > 0)
+                rl_print (i18n (1634, "ok.\n"));
         CONN_OK
     }
 }
 
 #define CONNS_FAIL_RC(s) { int rc = errno;            \
                            const char *t = s_sprintf ("%s: %s (%d).", s, strerror (rc), rc); \
-                           M_print (i18n (1949, "failed:\n"));  \
-                           M_printf ("%s [%d]\n", t, __LINE__);  \
+                           rl_print (i18n (1949, "failed:\n"));  \
+                           rl_printf ("%s [%d]\n", t, __LINE__);  \
                            if (conn->sok > 0)             \
                                sockclose (conn->sok);      \
                            conn->sok = -1;                  \
@@ -526,8 +529,8 @@ void UtilIOConnectF (Connection *conn)
     if (rc == -1)
         CONNS_FAIL_RC (i18n (2228, "Couldn't set FIFO nonblocking"));
 
-    if (M_pos () > 0)
-        M_print (i18n (1634, "ok.\n"));
+    if (rl_pos () > 0)
+        rl_print (i18n (1634, "ok.\n"));
 
     conn->connect = CONNECT_OK;
 }
@@ -559,7 +562,7 @@ static void UtilIOConnectCallback (Connection *conn)
     {
         eno = 0;
         rc = 0;
-        Debug (DEB_IO, "UtilIOConnectCallback: %x", conn->connect);
+        DebugH (DEB_IO, "UtilIOConnectCallback: %x", conn->connect);
         switch ((eno = conn->connect / CONNECT_SOCKS_ADD) % 7)
         {
             case 0:
@@ -624,7 +627,7 @@ static void UtilIOConnectCallback (Connection *conn)
                     conn->connect |= 8 * CONNECT_SOCKS_ADD;
                     conn->dispatch = conn->utilio;
                     EventD (QueueDequeue (conn, QUEUE_CON_TIMEOUT, conn->ip));
-                    UtilIOConnectTCP (conn);
+                    UtilIOConnectTCP (conn DEBUGNONE);
                     return;
                 }
                 if (buf[1])
@@ -690,7 +693,10 @@ Packet *UtilIOReceiveTCP (Connection *conn)
         return NULL;
     
     if (!(pak = conn->incoming))
+    {
         conn->incoming = pak = PacketC ();
+        memset (pak->data, 0, 6);
+    }
     
     if (conn->type == TYPE_SERVER)
     {
@@ -715,11 +721,7 @@ Packet *UtilIOReceiveTCP (Connection *conn)
 #if defined(SIGPIPE)
         signal (SIGPIPE, SIG_IGN);
 #endif
-#ifdef ENABLE_SSL
-        rc = ssl_sockread (conn, pak->data + pak->len, len - pak->len);
-#else
-        rc = sockread (conn->sok, pak->data + pak->len, len - pak->len);
-#endif /* ENABLE_SSL */        
+        rc = dc_read (conn, pak->data + pak->len, len - pak->len);
         if (rc <= 0)
         {
             if (!rc)
@@ -754,11 +756,7 @@ Packet *UtilIOReceiveTCP (Connection *conn)
         return NULL;
 
     PacketD (pak);
-#ifdef ENABLE_SSL
-    ssl_sockclose (conn);
-#else
-    sockclose (conn->sok);
-#endif /* ENABLE SSL */
+    dc_close (conn);
     conn->sok = -1;
     conn->incoming = NULL;
 
@@ -768,15 +766,10 @@ Packet *UtilIOReceiveTCP (Connection *conn)
         {
             Contact *cont;
             
-            if ((cont = ContactUIN (conn, conn->uin)))
+            if ((cont = conn->cont))
             {
-                M_printf ("%s %s%*s%s ", s_now, COLCONTACT, uiG.nick_len + s_delta (cont->nick), cont->nick, COLNONE);
-#ifdef ENABLE_SSL
-                if (conn->ssl_status == SSL_STATUS_OK)
-                    M_printf (i18n (2373, "Error while reading from socket (SSL): %s (%d)\n"), ssl_strerror (rc), rc);
-                else    
-#endif /* ENABLE SSL */
-                M_printf (i18n (1878, "Error while reading from socket: %s (%d)\n"), strerror (rc), rc);
+                rl_printf ("%s %s%*s%s ", s_now, COLCONTACT, uiG.nick_len + s_delta (cont->nick), cont->nick, COLNONE);
+                rl_printf (i18n (1878, "Error while reading from socket: %s (%d)\n"), dc_strerror (rc), rc);
             }
         }
         conn->connect = 0;
@@ -851,10 +844,10 @@ Packet *UtilIOReceiveF (Connection *conn)
         if (prG->verbose)
         {
             Contact *cont;
-            if ((cont = ContactUIN (conn, conn->uin)))
+            if ((cont = conn->cont))
             {
-                M_printf ("%s %s%*s%s ", s_now, COLCONTACT, uiG.nick_len + s_delta (cont->nick), cont->nick, COLNONE);
-                M_printf (i18n (1878, "Error while reading from socket: %s (%d)\n"), strerror (rc), rc);
+                rl_printf ("%s %s%*s%s ", s_now, COLCONTACT, uiG.nick_len + s_delta (cont->nick), cont->nick, COLNONE);
+                rl_printf (i18n (1878, "Error while reading from socket: %s (%d)\n"), strerror (rc), rc);
             }
         }
         conn->connect = 0;
@@ -877,7 +870,6 @@ BOOL UtilIOSendTCP (Connection *conn, Packet *pak)
     
     if (conn->outgoing)
         return FALSE;
-    
     conn->outgoing = pak;
 
     while (1)
@@ -886,11 +878,7 @@ BOOL UtilIOSendTCP (Connection *conn, Packet *pak)
 
         for ( ; pak->len > pak->rpos; pak->rpos += bytessend)
         {
-#ifdef ENABLE_SSL
-            bytessend = ssl_sockwrite (conn, data + pak->rpos, pak->len - pak->rpos);
-#else
-            bytessend = sockwrite (conn->sok, data + pak->rpos, pak->len - pak->rpos);
-#endif /* ENABLE_SSL */      
+            bytessend = dc_write (conn, data + pak->rpos, pak->len - pak->rpos);
             if (bytessend <= 0)
                 break;
         }
@@ -910,11 +898,7 @@ BOOL UtilIOSendTCP (Connection *conn, Packet *pak)
 
     conn->outgoing = NULL;
     PacketD (pak);
-#if ENABLE_SSL
-    ssl_sockclose (conn);
-#else
-    sockclose (conn->sok);
-#endif
+    dc_close (conn);
     conn->sok = -1;
 
     if ((rc && rc != ECONNRESET) || !conn->reconnect)
@@ -922,15 +906,11 @@ BOOL UtilIOSendTCP (Connection *conn, Packet *pak)
         if (prG->verbose || conn->type & TYPEF_ANY_SERVER)
         {
             Contact *cont;
-            if ((cont = ContactUIN (conn, conn->uin)))
+            
+            if ((cont = conn->cont))
             {
-                M_printf ("%s %s%*s%s ", s_now, COLCONTACT, uiG.nick_len + s_delta (cont->nick), cont->nick, COLNONE);
-#ifdef ENABLE_SSL
-                if (conn->ssl_status == SSL_STATUS_OK)
-                    M_printf (i18n (2373, "Error while reading from socket (SSL): %s (%d)\n"), ssl_strerror (rc), rc);
-                else    
-#endif /* ENABLE SSL */
-                    M_printf (i18n (1878, "Error while reading from socket: %s (%d)\n"), strerror (rc), rc);
+                rl_printf ("%s %s%*s%s ", s_now, COLCONTACT, uiG.nick_len + s_delta (cont->nick), cont->nick, COLNONE);
+                rl_printf (i18n (1878, "Error while reading from socket: %s (%d)\n"), dc_strerror (rc), rc);
             }
         }
         conn->connect = 0;
@@ -1002,34 +982,80 @@ Packet *UtilIOReceiveUDP (Connection *conn)
  *
  * Returned string may not be free()d.
  */
-char *UtilIOReadline (FILE *fd)
+strc_t UtilIOReadline (FILE *fd)
 {
-    static UDWORD size;
-    static char *t = NULL;
-    UDWORD pos = 0;
+    static str_s str;
     char *p;
     
-    if (!t)
-        t = malloc (size = 100);
-    *t = 0;
-    *(t + size - 2) = 0;
+    s_init (&str, "", 128);
     while (1)
     {
-        if (!fgets (t + pos, size - pos, fd))
+        str.txt[str.max - 2] = 0;
+        if (!fgets (str.txt + str.len, str.max - str.len, fd))
         {
-            if (!pos)
+            str.txt[str.len] = '\0';
+            if (!str.len)
                 return NULL;
-            else
-                break;
-        }
-        if (!*(t + size - 2))
             break;
-        t = realloc (t, size += 100);
-        pos = strlen (t);
-        *(t + size - 2) = 0;
+        }
+        str.txt[str.max - 1] = '\0';
+        str.len = strlen (str.txt);
+        if (!str.txt[str.max - 2])
+            break;
+        s_blow (&str, 128);
     }
-    *(t + size - 2) = 0;
-    if ((p = strpbrk (t, "\r\n")))
+    if ((p = strpbrk (str.txt, "\r\n")))
+    {
         *p = 0;
-    return t;
+        str.len = strlen (str.txt);
+    }
+    return &str;
+}
+
+static struct timeval tv;
+static fd_set fds[3];
+static int maxfd;
+
+void UtilIOSelectInit (int sec, int usec)
+{
+    FD_ZERO (&fds[0]);
+    FD_ZERO (&fds[1]);
+    FD_ZERO (&fds[2]);
+    tv.tv_sec = sec;
+    tv.tv_usec = usec;
+    maxfd = 0;
+}
+
+void UtilIOSelectAdd (FD_T sok, int nr)
+{
+    FD_SET (sok, &fds[nr & 3]);
+    if (sok > maxfd)
+        maxfd = sok;
+}
+
+BOOL UtilIOSelectIs (FD_T sok, int nr)
+{
+    return ((nr & READFDS)   && FD_ISSET (sok, &fds[READFDS & 3]))
+        || ((nr & WRITEFDS)  && FD_ISSET (sok, &fds[WRITEFDS & 3]))
+        || ((nr & EXCEPTFDS) && FD_ISSET (sok, &fds[EXCEPTFDS & 3]));
+}
+
+void UtilIOSelect (void)
+{
+    int res, rc;
+
+    errno = 0;
+    res = select (maxfd + 1, &fds[READFDS & 3], &fds[WRITEFDS & 3], &fds[EXCEPTFDS & 3], &tv);
+    rc = errno;
+    if (res == -1)
+    {
+        FD_ZERO (&fds[READFDS & 3]);
+        FD_ZERO (&fds[WRITEFDS & 3]);
+        FD_ZERO (&fds[EXCEPTFDS & 3]);
+        if (rc != EINTR && rc != EAGAIN)
+        {
+            printf (i18n (1849, "Error on select: %s (%d)\n"), strerror (rc), rc);
+            exit (0);
+        }
+    }
 }
