@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: util_opts.c,v 1.12 2005/04/20 20:13:59 kuhlmann Exp $
+ * $Id: util_opts.c,v 1.14 2005/12/11 20:57:29 kuhlmann Exp $
  */
                              
 #include "micq.h"
@@ -54,8 +54,10 @@ struct OptEntry_s OptList[] = {
   { "logmess",       CO_LOGMESS       },
   { "showonoff",     CO_SHOWONOFF     },
   { "showchange",    CO_SHOWCHANGE    },
+  { "autoauto",      CO_AUTOAUTO      },
   { "hideack",       CO_HIDEACK       },
   { "wantsbl",       CO_WANTSBL       },
+  { "peekme",        CO_PEEKME        },
   { "obeysbl",       CO_OBEYSBL       },
   { "shadow",        CO_SHADOW        },
   { "local",         CO_LOCAL         },
