@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: util_rl.c,v 1.44 2005/05/24 21:27:53 kuhlmann Exp $
+ * $Id: util_rl.c,v 1.48 2005/12/22 16:33:19 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -559,7 +559,10 @@ static void rl_recheck (BOOL clear)
         }
     }
 #ifdef ANSI_TERM
-    s_cat (&rl_operate, " \b");
+    if (!((rl_prompt_len + rl_colpos + 1) % rl_columns))
+        s_catf (&rl_operate, " \b\r" ESC "[%luC", rl_columns - 1);
+    else
+        s_cat (&rl_operate, " \b");
     if (clear)
         s_cat (&rl_operate, ANSI_CLEAR);
 #else
@@ -939,7 +942,7 @@ static const Contact *rl_tab_getnext (strc_t common)
                 rl_tab_state++;
             case 2:
                 while ((cont = ContactIndex (NULL, rl_tab_index++)))
-                    if (cont->status != STATUS_OFFLINE && !TabHas (cont))
+                    if (cont->status != STATUS_ICQOFFLINE && !TabHas (cont))
                     {
                         if (!strncasecmp (cont->nick, common->txt, common->len))
                             return cont;
@@ -952,7 +955,7 @@ static const Contact *rl_tab_getnext (strc_t common)
                 rl_tab_state++;
             case 3:
                 while ((cont = ContactIndex (NULL, rl_tab_index++)))
-                    if (cont->status == STATUS_OFFLINE && !TabHas (cont))
+                    if (cont->status == STATUS_ICQOFFLINE && !TabHas (cont))
                     {
                         if (!strncasecmp (cont->nick, common->txt, common->len))
                             return cont;
@@ -986,7 +989,7 @@ static const Contact *rl_tab_getprev (strc_t common)
         {
             case 3:
                 while (rl_tab_index && (cont = ContactIndex (NULL, --rl_tab_index)))
-                    if (cont->status == STATUS_OFFLINE && !TabHas (cont))
+                    if (cont->status == STATUS_ICQOFFLINE && !TabHas (cont))
                     {
                         rl_tab_index++;
                         if (!strncasecmp (cont->nick, common->txt, common->len))
@@ -1002,7 +1005,7 @@ static const Contact *rl_tab_getprev (strc_t common)
                 rl_tab_state--;
             case 2:
                 while (rl_tab_index && (cont = ContactIndex (NULL, --rl_tab_index)))
-                    if (cont->status != STATUS_OFFLINE && !TabHas (cont))
+                    if (cont->status != STATUS_ICQOFFLINE && !TabHas (cont))
                     {
                         rl_tab_index++;
                         if (!strncasecmp (cont->nick, common->txt, common->len))
@@ -1809,7 +1812,7 @@ void ReadLinePromptSet (const char *prompt)
 {
     rl_prompt_time = time (NULL);
     s_init (&rl_prompt, COLSERVER, 0);
-    s_cat  (&rl_prompt, ConvTo (prompt, ENC(enc_loc))->txt);
+    s_cat  (&rl_prompt, prompt);
     s_cat  (&rl_prompt, COLNONE);
     s_catc (&rl_prompt, ' ');
     if (rl_prompt_stat != 0)
