@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: util_ssl.c,v 1.24 2005/04/09 13:45:03 kuhlmann Exp $
+ * $Id: util_ssl.c,v 1.25 2005/07/15 21:23:21 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -180,6 +180,15 @@ int SSLInit ()
     int ret;
 
     ssl_init_ok = 0;
+    
+#if ENABLE_AUTOPACKAGE
+    extern int libgnutls_is_present;
+    if (!libgnutls_is_present)
+    {
+        rl_printf (i18n (2581, "Install the GnuTLS library and enjoy encrypted connections to peers!\n"));
+        return -1;
+    }
+#endif
 
     ret = gnutls_global_init ();
     SSL_CHECK_SUCCESS_0_OK (ret, -1, "gnutls_global_init", NULL);
