@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: util_str.c,v 1.75 2004/12/05 14:55:31 kuhlmann Exp $
+ * $Id: util_str.c,v 1.77 2005/12/22 16:33:19 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -318,23 +318,23 @@ const char *s_status (UDWORD status)
 {
     static char buf[200];
     
-    if (status == STATUS_OFFLINE)
+    if (status == STATUS_ICQOFFLINE)
         return i18n (1969, "offline");
  
-    if (status & STATUSF_INV)
+    if (status & STATUSF_ICQINV)
         snprintf (buf, sizeof (buf), "%s-", i18n (1975, "invisible"));
     else
         buf[0] = '\0';
     
-    if (status & STATUSF_DND)
+    if (status & STATUSF_ICQDND)
         snprintf (buf + strlen (buf), sizeof(buf) - strlen (buf), "%s", i18n (1971, "do not disturb"));
-    else if (status & STATUSF_OCC)
+    else if (status & STATUSF_ICQOCC)
         snprintf (buf + strlen (buf), sizeof(buf) - strlen (buf), "%s", i18n (1973, "occupied"));
-    else if (status & STATUSF_NA)
+    else if (status & STATUSF_ICQNA)
         snprintf (buf + strlen (buf), sizeof(buf) - strlen (buf), "%s", i18n (1974, "not available"));
-    else if (status & STATUSF_AWAY)
+    else if (status & STATUSF_ICQAWAY)
         snprintf (buf + strlen (buf), sizeof(buf) - strlen (buf), "%s", i18n (1972, "away"));
-    else if (status & STATUSF_FFC)
+    else if (status & STATUSF_ICQFFC)
         snprintf (buf + strlen (buf), sizeof(buf) - strlen (buf), "%s", i18n (1976, "free for chat"));
     else if (buf[0])
         buf[strlen (buf) - 1] = '\0';
@@ -356,6 +356,7 @@ const char *s_time (time_t *stamp)
     struct tm now;
     struct tm *thetime;
     static char tbuf[40];
+    str_s str = { NULL, 0, 0 };
     time_t nowsec;
 
 #ifdef HAVE_GETTIMEOFDAY
@@ -374,9 +375,9 @@ const char *s_time (time_t *stamp)
 
     thetime = (!stamp || *stamp == NOW) ? &now : localtime (stamp);
 
-    strftime(tbuf, sizeof (tbuf), thetime->tm_year == now.tm_year 
+    strftime (tbuf, sizeof (tbuf), thetime->tm_year == now.tm_year 
         && thetime->tm_mon == now.tm_mon && thetime->tm_mday == now.tm_mday
-        ? "%H:%M:%S" : "%a %b %d %H:%M:%S %Y", thetime);
+        ? "%H:%M:%S" : "%a %b %d %H:%M:%S %Y", thetime); /*"*/
 
     if (prG->verbose > 7)
         snprintf (tbuf + strlen (tbuf), sizeof (tbuf) - strlen (tbuf),
@@ -385,7 +386,9 @@ const char *s_time (time_t *stamp)
         snprintf (tbuf + strlen (tbuf), sizeof (tbuf) - strlen (tbuf),
                   ".%.03ld", !stamp || *stamp == NOW ? p.tv_usec / 1000 : 0);
     
-    return tbuf;
+    str.txt = tbuf;
+    str.len = strlen (tbuf);
+    return ConvFrom (&str, prG->enc_loc)->txt;
 }
 
 /*
