@@ -26,7 +26,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  *
- * $Id: util_syntax.c,v 1.30 2005/02/27 21:42:25 kuhlmann Exp $
+ * $Id: util_syntax.c,v 1.32 2005/12/23 02:34:45 kuhlmann Exp $
  */
 
 #include "micq.h"
@@ -52,8 +52,11 @@ static const char *syntable[] = {
     "s1x23s",  "D-",
     "s1x24s",  "D-",
     "s1x30s",  "t[12gp2p]-",
+    "s2x1s",   "Wt[8W]",
     "s2x3s",   "t-",
     "s2x4s",   "t[5C-]-",
+    "s2x5s",   "Wu",
+    "s2x6s",   "uWW{t[1D][6D][12gp2p][10D][15D][3D][5D]}t[1][2][3][4][5C-]-",
     "s3x1s",   "WWu-",
     "s3x2s",   "",
     "s3x3s",   "t-",
@@ -84,10 +87,10 @@ static const char *syntable[] = {
     "s19x6s",  "bWgs19x6cs",
     "s19x6cs", "BWWW<t-)gs19x6cs",
     "s19x7s",  "",
-    "s19x8s",  ")uWWWWt-",
-    "s19x9s",  "BWWWWt-",
+    "s19x8s",  "BWWW<t-)gs19x8s",
+    "s19x9s",  "BWWW<t-)gs19x9s",
     "s19x10s", "uWWWWt-",
-    "s19x14s", "W",
+    "s19x14s", "W-",
     "s19x15s", "DW",
     "s19x17s", "",
     "s19x18s", "",
